<?php

if ( ! defined( 'ABSPATH' ) ) exit;

use Delipress\WordPress\Helpers\TaxonomyHelper;
use Delipress\WordPress\Models\SubscriberModel;

function checkDelipressPluginExist(){
    global $delipressPlugin;

    if(!isset($delipressPlugin) ) {
        return false;
    }

    return true;
}

/**
 *
 * @param string $name
 * 
 * @param array $params
 * @example $metas = array(
 *      TaxonomyHelper::META_LIST_COLOR => "#ffffff"
 * )
 * 
 * @return array
 */
function delipress_create_list($name, $metas = array()){

    if(!checkDelipressPluginExist()){
        return null;
    }

    if(empty($name)){
        return array(
            "success" => false,
            "results" => array(
                "message" => __("Name is empty", "delipress")
            ) 
        );
    }

    $params = array(
        TaxonomyHelper::LIST_NAME => $name
    );

    global $delipressPlugin;

    return $delipressPlugin->getService("CreateListServices")->createListStandalone($params, $metas);
    
}

/**
 *
 * @param string $email
 * @param int $listId
 * 
 * @param array $metas
 * @example $metas = array(
 *      "first_name" => "John",
 *      "last_name"  => "Doe"
 * )
 * 
 * @return array
 */
function delipress_create_subscriber_on_list($email, $listId, $metas = array()){

    if(!checkDelipressPluginExist()){
        return null;
    }

    if(empty($email)){
        return array(
            "success" => false,
            "results" => array(
                "message" => __("Email is empty", "delipress") 
            ) 
        );
    }

    if(empty($listId)){
        return array(
            "success" => false,
            "results" => array(
                "message" => __("List id is empty", "delipress") 
            ) 
        );
    }

    global $delipressPlugin;

    $createSubscriberServices = $delipressPlugin->getService("CreateSubscriberServices");

    $params = array(
        "email"   => $email
    );
    
    $emailVerify = $createSubscriberServices->checkSubscriberExistByEmail($email, "obj");
    if($emailVerify instanceof SubscriberModel){
        $params["subscriber"] = $emailVerify;
    }

    $list = $createSubscriberServices->checkListExist($listId);
    if($list === null){
        return array(
            "success" => false,
            "results" => array(
                "message" => __("List not exist", "delipress")
            )
        );
    }

    $params["list_id"] = $list;

    $params = array_merge($metas, $params);

    return $createSubscriberServices->createSubscriberOnListFromAdministration($params);
    
}



/**
 *
 * @param int $listId
 * @param int $subscriberId
 * 
 * @param array $params
 * @example $params = array(
 *      "email" => "support@delipress.io"
 * )
 * 
 * @param array $metas
 * @example $metas = array(
 *      "first_name" => "John",
 *      "last_name"  => "Doe"
 * )
 * 
 * @return array
 */
function delipress_edit_subscriber_on_list($listId, $subscriberId, $params, $metas = array() ){

    if(!checkDelipressPluginExist()){
        return null;
    }

    if(empty($listId)){
        return array(
            "success" => false,
            "results" => array(
                "message" => __("List id is empty", "delipress")
            ) 
        );
    }

    if(empty($subscriberId)){
        return array(
            "success" => false,
            "results" => array(
                "message" => __("Subscriber id is empty", "delipress")
            ) 
        );
    }

    global $delipressPlugin;

    $createSubscriberServices = $delipressPlugin->getService("CreateSubscriberServices");
    return $createSubscriberServices->editSynchronizeSubscriber($listId, $subscriberId, $params, $metas);
    
}


