<?php

namespace DeliSkypress\Services\Specification;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\SpecificationFactoryInterface;
use DeliSkypress\Models\ServiceInterface;
use DeliSkypress\Factory\Specification\SpecificationFactory;

class Specification implements ServiceInterface
{
    
    /**
     *
     * @param SpecificationFactoryInterface $factory
     */
    public function __construct(SpecificationFactoryInterface $factory = null){
        $this->conditionTest = apply_filters('_specification_condition_test', array(
            "equals"       => __('Equals', 'skypress'),
            "contains"     => __('Contains', 'skypress'),
            "not_equals"   => __('Not equals', 'skypress'), 
            "not_contains" => __('Not contains', 'skypress')
        ));

        $this->specificationFactory = $factory;
    }

    /**
     *
     * @return SpecificationFactory
     */
    public function getSpecificationFactory(){
        if (is_null($this->specificationFactory)) {
            $this->specificationFactory = $this->createDefaultSpecificationFactory();
        }

        return $this->specificationFactory;
    }

    /**
     *
     * @return SpecificationFactory
     */
    public function createDefaultSpecificationFactory(){
        return new SpecificationFactory();
    }
    
    /**
     *
     * @param SpecificationFactoryInterface $factory
     * @return Specification
     */
    public function setFactory(SpecificationFactoryInterface $factory){
        $this->specificationFactory = $factory;
        return $this;
    }

    /**
     *
     * @param array $data
     * @return Specification
     */
    public function constructSpecification($data){
        return $this->getSpecificationFactory()
                    ->constructSpecification($data);
    }
}