<?php

namespace Delipress\WordPress\Admin\Listing;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\HooksInterface;
use DeliSkypress\Models\ContainerInterface;
use DeliSkypress\WordPress\Actions\AbstractHook;

use Delipress\WordPress\Helpers\ActionHelper;
use Delipress\WordPress\Helpers\AdminNoticesHelper;
use Delipress\WordPress\Helpers\CodeErrorHelper;
use Delipress\WordPress\Models\ListModel;

/**
 * SynchronizeManuallyList
 *
 * @author DeliPress
 * @version 1.0.0
 * @since 1.0.0
 */
class SynchronizeManuallyList extends AbstractHook implements HooksInterface {

    /**
     *  @param ContainerInterface $containerServices
     *  @see AbstractHook
     */
    public function setContainerServices(ContainerInterface $containerServices){
        $this->providerServices = $containerServices->getService("ProviderServices");
        $this->optionServices   = $containerServices->getService("OptionServices");
        $this->listServices     = $containerServices->getService("ListServices");
    }

    /**
     * @see HooksInterface
     */
    public function hooks(){
        if(current_user_can('manage_options' ) ){
            add_action( 'admin_post_' . ActionHelper::SYNCHRONIZE_LIST_SUBSCRIBER_IMPORT, array($this, 'synchronizeManuallyImport') );
            add_action( 'admin_post_' . ActionHelper::SYNCHRONIZE_LIST_SUBSCRIBER_EXPORT, array($this, 'synchronizeManuallyExport') );
        }
    }

    /**
     * @see admin_post_ ActionHelper::SYNCHRONIZE_LIST_SUBSCRIBER_IMPORT
     * 
     * @return void
     */
    public function synchronizeManuallyImport(){
        if ( 
            ! isset( $_GET['_wpnonce'] ) || 
            ! wp_verify_nonce( $_GET['_wpnonce'], ActionHelper::SYNCHRONIZE_LIST_SUBSCRIBER_IMPORT ) ||
            ! isset($_GET["list_id"])

        ) {
            wp_nonce_ays( '' );
        }
        
        $provider = $this->optionServices->getProvider();
        if(!$provider["is_connect"]){
            $url      = $this->listServices->getPageListUrl();
            wp_redirect($url);
            exit;
        }

        $listId   = (int) $_GET["list_id"];
        
        $list = new ListModel();
        $list->setListByTermId($listId);

        $response = $this->providerServices
                        ->getProviderImport($provider["key"])
                        ->synchronizeListSubscriberForBackgroundProcess($list);

        if($response["success"]){
            AdminNoticesHelper::registerSuccess(
                CodeErrorHelper::ADMIN_NOTICE,
                __("List import in progress", "delipress") 
            );
        }

        $url      = $this->listServices->getPageListUrl();

        wp_redirect($url);
        exit;
    } 

    /**
     * @see admin_post_ ActionHelper::SYNCHRONIZE_LIST_SUBSCRIBER_EXPORT
     * 
     * @return void
     */
    public function synchronizeManuallyExport(){
        if ( 
            ! isset( $_GET['_wpnonce'] ) || 
            ! wp_verify_nonce( $_GET['_wpnonce'], ActionHelper::SYNCHRONIZE_LIST_SUBSCRIBER_EXPORT ) ||
            ! isset($_GET["list_id"])

        ) {
            wp_nonce_ays( '' );
        }
        
        $provider = $this->optionServices->getProvider();
        if(!$provider["is_connect"]){
            $url      = $this->listServices->getPageListUrl();
            wp_redirect($url);
            exit;
        }

        $listId   = (int) $_GET["list_id"];
        
        $list = new ListModel();
        $list->setListByTermId($listId);

        $response = $this->providerServices
                        ->getProviderExport($provider["key"])
                        ->prepareListsForBackgroundProcessWithList($list);

        if($response["success"]){
            AdminNoticesHelper::registerSuccess(
                CodeErrorHelper::ADMIN_NOTICE,
                __("List export in progress", "delipress") 
            );
        }

        $url      = $this->listServices->getPageListUrl();

        wp_redirect($url);
        exit;
    } 

}









