<?php

namespace Delipress\WordPress\Admin;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\ContainerInterface;
use DeliSkypress\Models\HooksAdminInterface;
use DeliSkypress\WordPress\Actions\AbstractHook;

use Delipress\WordPress\Helpers\PostTypeHelper;

/**
 * Migration
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class Migration extends AbstractHook implements HooksAdminInterface {


    /**
     *  @param ContainerInterface $containerServices
     *  @see AbstractHook
     */
    public function setContainerServices(ContainerInterface $containerServices){
        $this->optionServices              = $containerServices->getService("OptionServices");
        $this->optinStatsTableServices     = $containerServices->getService("OptinStatsTableServices");
        $this->metaTableServices           = $containerServices->getService("MetaTableServices");
        $this->subscriberMetaTableServices = $containerServices->getService("SubscriberMetaTableServices");
    }

    /**
     * @see HooksAdminInterface
     */
    public function hooks(){
        if(DELIPRESS_VERSION !== "{VERSION}"){
            add_action("admin_init", array($this, "upgradeVersion"), 9999);
        }
    }

    /**
     * Upgrade version DeliPress
     * @see admin_init
     * @return void
     */
    public function upgradeVersion(){
        $version       = $this->optionServices->getVersion();

        $hasOneUpdate = false;
        if(version_compare($version, "0.10.0", "<") || $version === null){
            $hasOneUpdate = true;
            $this->optinStatsTableServices->createTable();
        }

        if(version_compare($version, "1.0.4", "<") || $version === null){
            $hasOneUpdate = true;
            $this->metaTableServices->createTable();
            $this->subscriberMetaTableServices->createTable();
        }

        if($hasOneUpdate){
            $this->optionServices->updateVersion();
        }

    }

}
