<?php

namespace Delipress\WordPress\Admin\Wizard;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\HooksInterface;
use DeliSkypress\Models\ContainerInterface;
use DeliSkypress\WordPress\Actions\AbstractHook;

use Delipress\WordPress\Helpers\OptionHelper;
use Delipress\WordPress\Helpers\PageAdminHelper;
use Delipress\WordPress\Helpers\ProviderHelper;
use Delipress\WordPress\Services\Wizard\WizardServices;

use Delipress\WordPress\Helpers\ActionHelper;

/**
 * WizardStepTwo
 *
 * @author DeliPress
 * @version 1.0.0
 * @since 1.0.0
 */
class WizardStepTwo extends AbstractHook implements HooksInterface {

    /**
     *  @param ContainerInterface $containerServices
     *  @see AbstractHook
     */
    public function setContainerServices(ContainerInterface $containerServices){
        $this->wizardServices           = $containerServices->getService("WizardServices");
        $this->wizardStepTwoServices    = $containerServices->getService("WizardStepTwoServices");
    }

    /**
     * @see HooksInterface
     */
    public function hooks(){
        if(current_user_can('manage_options' ) ){
            add_action( 'admin_post_' . ActionHelper::WIZARD_STEP_2_SYNCHRONIZE, array($this, 'importLists') );
            add_action( 'admin_post_' . ActionHelper::WIZARD_STEP_2_CREATE_LIST, array($this, 'createList') );
        }
    }


    public function importLists(){
        if (
            ! isset( $_GET['_wpnonce'] ) ||
            ! wp_verify_nonce( $_GET['_wpnonce'], ActionHelper::WIZARD_STEP_2_SYNCHRONIZE ) ||
            $_SERVER["REQUEST_METHOD"] !== "POST" ||
            ! isset( $_POST["provider"])
        ) {
            wp_nonce_ays( '' );
        }


        $provider = ProviderHelper::getProviderFromPostRequest();

        $response = $this->wizardStepTwoServices->importLists($provider["key"]);

        set_transient(WizardServices::STEP_WIZARD, 3);

        $url = $this->wizardServices->getPageWizard(2, array(
                "tab"      => "finish_synchronize"
            )
        );

        wp_redirect($url);
        exit;

    }

    public function createList(){
        if (
            ! isset( $_GET['_wpnonce'] ) ||
            ! wp_verify_nonce( $_GET['_wpnonce'], ActionHelper::WIZARD_STEP_2_CREATE_LIST ) ||
            $_SERVER["REQUEST_METHOD"] !== "POST"
        ) {
            wp_nonce_ays( '' );
        }

        $response = $this->wizardStepTwoServices->createList();

        if($response["success"]){

            set_transient(WizardServices::STEP_WIZARD, 3);

            $url = $this->wizardServices->getPageWizard(2, array(
                    "tab"      => "finish_add_list"
                )
            );
        }
        else{
            $url = $this->wizardServices->getPageWizard(2, array(
                    "tab" => "add_list"
                )
            );
        }

        wp_redirect($url);
        exit;

    }

}
