<?php

namespace Delipress\WordPress\Async;

use Delipress\WordPress\Async\WPBackgroundProcess;

use Delipress\WordPress\Models\ListModel;


class ExportToProviderBackgroundProcess extends WPBackgroundProcess {

	protected $action    = 'delipress_export_to_provider_background';

	protected $transient = 'delipress_sync_export_background';

	public function __construct($providerServices, $optionServices) {
		parent::__construct();

		$this->providerServices = $providerServices;
        $this->optionServices   = $optionServices;
	}


	/**
	 * Task
	 *
	 * Override this method to perform any actions required on each
	 * queue item. Return the modified item for further processing
	 * in the next pass through. Or, return false to remove the
	 * item from the queue.
	 *
	 * @param mixed $item Queue item to iterate over
	 *
	 * @return mixed
	 */
	protected function task( $item ) {

		$providerExport = $this->providerServices
                         	   ->getProviderExport($item["provider"]);

		$listModel = new ListModel();
		$listModel->setListByTermId(
			$item["list_id"]
		);

		$providerExport->exportListContacts($listModel, $item["page"], $item["limit"]);

		if ( false === ( $transient = get_transient( $this->transient ) ) ){
            $transient = array();
		}
        
		if($item["page"] < $item["total"]){
			$transient[$item["list_id"]] = 1;
		}
		else{
			$transient[$item["list_id"]] = 0;
		}


		set_transient($this->transient, $transient);

		return false;
	}

	/**
	 * Complete
	 *
	 * Override if applicable, but ensure that the below actions are
	 * performed, or, call parent::complete().
	 */
	protected function complete() {
		parent::complete();
		delete_transient($this->transient);
	}
}