<?php

namespace Delipress\WordPress\Front;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\HooksInterface;
use DeliSkypress\Models\ActivationInterface;
use DeliSkypress\Models\ContainerInterface;
use DeliSkypress\WordPress\Actions\AbstractHook;

use Delipress\WordPress\Helpers\ActionHelper;
use Delipress\WordPress\Helpers\DataEncoder;

use Delipress\WordPress\Models\ListModel;
use Delipress\WordPress\Models\SubscriberModel;

/**
 * PageConfirmSubscribe
 *
 * @author DeliPress
 * @version 1.0.0
 * @since 1.0.0
 */
class PageConfirmSubscribe extends AbstractHook implements HooksInterface {
    
    /**
     *  @param ContainerInterface $containerServices
     *  @see AbstractHook
     */
    public function setContainerServices(ContainerInterface $containerServices){
        $this->confirmSubscribeServices           = $containerServices->getService("ConfirmSubscribeServices");
    }

    /**
     * @see HooksInterface
     */
    public function hooks(){
        add_action("init", array($this,"pageRequestConfirmSubscribe"));
    }


    /**
     * @action DELIPRESS_SLUG . "_before_page_confirm_subscribe"
     * @action DELIPRESS_SLUG . "_after_page_confirm_subscribe"
     * 
     * @return void
     */
    public function pageRequestConfirmSubscribe(){
        
        if(  
            !isset( $_GET["action"]) || 
            !isset($_GET["data"] ) || 
            !isset($_GET["_wpnonce"])
        ){
            return;
        }
        $data = DataEncoder::decodeData($_GET["data"]);
        if(
            empty($data) || 
            !array_key_exists("subscriber_id", $data) ||
            !array_key_exists("subscriber_email", $data) ||
            !$data["subscriber_id"] ||
            !$data["subscriber_email"]
        ){
            return;
        }
        

        $this->subscriber = new SubscriberModel();
        $this->subscriber->setSubscriberById($data["subscriber_id"]);

        if( !$this->subscriber ||
            $this->subscriber->getEmail() !== $data["subscriber_email"]
        ){
            return;
        }

        $this->confirmSubscribeServices->confirmSubscriber($this->subscriber);

        do_action(DELIPRESS_SLUG . "_before_page_confirm_subscribe");
        
        include_once apply_filters("delipress_page_request_confirm_subscribe", DELIPRESS_PLUGIN_DIR_TEMPLATES_FRONT . "/confirm_subscribe.php");

        do_action(DELIPRESS_SLUG . "_after_page_confirm_subscribe");

        die;
    }

}