<?php

namespace Delipress\WordPress\Front;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\HooksInterface;
use DeliSkypress\Models\ActivationInterface;
use DeliSkypress\Models\ContainerInterface;
use DeliSkypress\WordPress\Actions\AbstractHook;

use Delipress\WordPress\Helpers\ActionHelper;
use Delipress\WordPress\Helpers\DataEncoder;

use Delipress\WordPress\Models\ListModel;
use Delipress\WordPress\Models\SubscriberModel;

/**
 * PageUnsubscribe
 *
 * @author DeliPress
 * @version 1.0.0
 * @since 1.0.0
 */
class PageUnsubscribe extends AbstractHook implements HooksInterface {
    
    /**
     *  @param ContainerInterface $containerServices
     *  @see AbstractHook
     */
    public function setContainerServices(ContainerInterface $containerServices){
        $this->unsubscribeServices          = $containerServices->getService("UnsubscribeServices");
        $this->subscriberServices           = $containerServices->getService("SubscriberServices");
        $this->deleteSubscriberServices     = $containerServices->getService("DeleteSubscriberServices");
    }

    /**
     * @see HooksInterface
     */
    public function hooks(){
        add_action("init", array($this,"pageRequestUnsubscribe"));
        add_action("init", array($this,"pageUnsubscribe"));
        add_action( 'wp_ajax_nopriv_delipress_request_unsubscribe', array($this, 'postPageRequestUnsubscribe') );
        add_action( 'wp_ajax_delipress_request_unsubscribe', array($this, 'postPageRequestUnsubscribe') );
    }



    /**
     * @action DELIPRESS_SLUG . "_before_post_page_request_unsubscribe"
     * @action DELIPRESS_SLUG . "_after_post_page_request_unsubscribe"
     * 
     * @return void
     */
    public function postPageRequestUnsubscribe(){
        if(  
            !isset( $_POST["action"]) || 
            $_POST["action"] != ActionHelper::REQUEST_UNSUBSCRIBE ||
            !isset( $_GET["_wpnonce"]) ||
            !isset( $_GET["list_id"]) ||
            ! wp_verify_nonce( $_GET['_wpnonce'], ActionHelper::REQUEST_UNSUBSCRIBE )
        ){
            return;
        }

        do_action(DELIPRESS_SLUG . "_before_post_page_request_unsubscribe");

        $result = $this->unsubscribeServices->sendRequestUnsubscribe();

        do_action(DELIPRESS_SLUG . "_after_post_page_request_unsubscribe");

        wp_send_json_success($result["success"]);

        die;
    }


    /**
     * @action DELIPRESS_SLUG . "_before_get_page_request_unsubscribe"
     * @action DELIPRESS_SLUG . "_after_get_page_request_unsubscribe"
     * 
     * @return void
     */
    public function pageRequestUnsubscribe(){
        if(  
            $_SERVER["REQUEST_METHOD"] !== "GET" ||
            !isset( $_GET["action"]) || 
            $_GET["action"] != ActionHelper::REQUEST_UNSUBSCRIBE ||
            !isset( $_GET["list_id"])
        ){
            return;
        }

        do_action(DELIPRESS_SLUG . "_before_get_page_request_unsubscribe");
        
        include_once apply_filters("delipress_page_request_unsubscribe", DELIPRESS_PLUGIN_DIR_TEMPLATES_FRONT . "/request_unsubscribe.php");

        do_action(DELIPRESS_SLUG . "_after_get_page_request_unsubscribe");

        die;

    }

    /**
     * @action DELIPRESS_SLUG . "_before_page_unsubscribe"
     * @action DELIPRESS_SLUG . "_after_page_unsubscribe"
     * 
     * @return void
     */
    public function pageUnsubscribe(){
        
        if(  
            !isset( $_GET["action"]) || 
            !isset($_GET["data"] ) || 
            !isset($_GET["_wpnonce"]) ||
            !isset($_GET["token"]) ||
            $_GET["action"] != ActionHelper::UNSUBSCRIBE ||
            ! wp_verify_nonce( $_GET['_wpnonce'], ActionHelper::UNSUBSCRIBE )
        ){
            return;
        }
        $data = DataEncoder::decodeData($_GET["data"]);
        
        if(
            empty($data) || 
            !array_key_exists("list_id", $data) ||
            !array_key_exists("subscriber_id", $data) ||
            !array_key_exists("subscriber_email", $data) ||
            !$data["list_id"] ||
            !$data["subscriber_id"] ||
            !$data["subscriber_email"]
        ){
            return;
        }
        
        $this->list = new ListModel();
        $this->list->setListByTermId($data["list_id"]);

        $this->subscriber = new SubscriberModel();
        $this->subscriber->setSubscriberById($data["subscriber_id"]);

        if( !$this->subscriber ||
            $this->subscriber->getEmail() !== $data["subscriber_email"]
        ){
            return;
        }

        $token = sanitize_text_field($_GET["token"]);
        $authorize = $this->unsubscribeServices->verifyTokenUnsubscribe($token, $this->list, $this->subscriber);

        if(!$authorize){
            wp_redirect(home_url());
            exit;
        }

        $this->deleteSubscriberServices->deleteSubscriberOnList($this->list, $this->subscriber);

        do_action(DELIPRESS_SLUG . "_before_page_unsubscribe");
        
        include_once apply_filters("delipress_page_unsubscribe_success", DELIPRESS_PLUGIN_DIR_TEMPLATES_FRONT . "/unsubscribe.php");

        do_action(DELIPRESS_SLUG . "_after_page_unsubscribe");

        die;
    }

}