<?php

namespace Delipress\WordPress\Front;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\HooksInterface;
use DeliSkypress\Models\ActivationInterface;
use DeliSkypress\Models\ContainerInterface;
use DeliSkypress\WordPress\Actions\AbstractHook;

use Delipress\WordPress\Helpers\ActionHelper;
use Delipress\WordPress\Helpers\ProviderHelper;

/**
 * WebhookProvider
 *
 * @author DeliPress
 * @version 1.0.0
 * @since 1.0.0
 */
class WebhookProvider extends AbstractHook implements HooksInterface {
    
    /**
     *  @param ContainerInterface $containerServices
     *  @see AbstractHook
     */
    public function setContainerServices(ContainerInterface $containerServices){
        $this->optionServices   = $containerServices->getService("OptionServices");
        $this->providerServices = $containerServices->getService("ProviderServices");
    }

    /**
     * @see HooksInterface
     */
    public function hooks(){
        add_action('init', array($this, "webhookUrl"), 1);
        add_action( 'wp_loaded',array($this, "flushRules") );

        add_filter("template_redirect", array($this,"routerWebhook"));
    }  

    /**
     * @see init
     *
     * @return void
     */
    public function flushRules(){
        $rules = get_option( 'rewrite_rules' );

        if ( ! isset( $rules['delipress/webhooks/([^/]+)/([^/]+)/?$'] ) ) {
            global $wp_rewrite;
            $wp_rewrite->flush_rules();
        }
    }

    /**
     * @see init
     * @return void
     */
    public function webhookUrl(){

        add_rewrite_tag('%action%','([^&]+)');
        add_rewrite_tag('%provider%','([^&]+)');

        add_rewrite_rule('delipress/webhooks/([^/]+)/([^/]+)/?$', 'index.php?action=$matches[1]&provider=$matches[2]', 'top');
    }


    /**
     * @action DELIPRESS_SLUG . "_before_router_webhook"
     * @action DELIPRESS_SLUG . "_after_router_webhook"
     * 
     * @return void
     */
    public function routerWebhook(){
        
        $action   = get_query_var("action");
        $provider = get_query_var("provider");

        if(
            empty($action) ||
            empty($provider)
        ){
            return;
        }

        $provider = ProviderHelper::getProviderByKey($provider);
        if($provider === null){
            return;
        }

        $providerOption = $this->optionServices->getProvider();
        if(!$providerOption["is_connect"]){
            wp_redirect(home_url());
            exit;
        }
        
        if($providerOption["key"] !== $provider["key"]){
            wp_redirect(home_url());
            exit;
        }

        add_action('wp_head', array($this, "preventMeta"));

        do_action(DELIPRESS_SLUG . "_before_router_webhook");

        switch($action){
            case ActionHelper::PROVIDER_WEBHOOK_UNSUBSCRIBE:
                $this->webhookUnsubscribe($provider);
                break;
            case ActionHelper::PROVIDER_WEBHOOK_SUBSCRIBE:
                $this->webhookSubscribe($provider);
                break;
        }

        do_action(DELIPRESS_SLUG . "_after_router_webhook");
    }

    /**
     * @see wp_head
     * @return void
     */
    public function preventMeta(){
        ?>
        <meta name="robots" content="noindex, nofollow">
        <?php
    }

    /**
     *
     * @param string $provider
     * @return void
     */
    protected function endWebhook($provider, $type){

        do_action(DELIPRESS_SLUG . "_end_webhook_" . $type);

        switch($provider){
            case ProviderHelper::MAILJET:
                status_header(200);
            break;
            default:
                status_header(200);
                // wp_redirect(home_url());
                // exit;
                break;
        }
    }

    /**
     * @action DELIPRESS_SLUG . "_before_webhook_unsubscribe"
     * @action DELIPRESS_SLUG . "_after_webhook_unsubscribe"
     * 
     * @return void
     */
    public function webhookUnsubscribe($provider){

        do_action(DELIPRESS_SLUG . "_before_webhook_unsubscribe_" . $provider["key"]);

        $this->providerServices
             ->getProviderWebhook($provider["key"])
             ->webhookUnsubscribe();


        do_action(DELIPRESS_SLUG . "_after_webhook_unsubscribe_" . $provider["key"]);

        $this->endWebhook($provider["key"], "unsubscribe");
    }
    /**
     * @action DELIPRESS_SLUG . "_before_webhook_subscribe"
     * @action DELIPRESS_SLUG . "_after_webhook_subscribe"
     * 
     * @return void
     */
    public function webhookSubscribe($provider){

        do_action(DELIPRESS_SLUG . "_before_webhook_subscribe_" . $provider["key"]);

        $this->providerServices
             ->getProviderWebhook($provider["key"])
             ->webhookSubscribe();

        do_action(DELIPRESS_SLUG . "_after_webhook_subscribe_" . $provider["key"]);

        $this->endWebhook($provider["key"], "subscribe");
    }

}