<?php

namespace Delipress\WordPress\Helpers;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );


/**
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
abstract class OptinHelper{

    const POPUP                  = "popup_optin";
    const SMARTBAR               = "smartbar_optin";
    const FLY                    = "fly_optin";
    const WIDGET                 = "widget_optin";
    const AFTER_CONTENT          = "after_content_optin";
    const LOCKED                 = "locked_optin";
    const SHORTCODE              = "shortcode_optin";
    const WOOCOMMERCE_ORDER      = "woocommerce_order_optin";

    const COUNTER_VIEW           = "counter_view";
    const COUNTER_CONVERT        = "counter_convert";

    protected static $loaded = false;


    public static function loadOptinScript($load){

        self::$loaded = true;

        $loadAfterAdmin = false;
        if ( current_theme_supports( 'admin-bar' ) && is_user_logged_in()) {
            $loadAfterAdmin = 'admin-bar';
        }
        
        wp_enqueue_style( 'delipress-style', DELIPRESS_PATH_PUBLIC_CSS.'/optins.css' );

        wp_register_script( 'delipress-optin',  DELIPRESS_PATH_PUBLIC_JS.'/optins.js' , $loadAfterAdmin, false, true );
        wp_enqueue_script( 'delipress-optin' );
        
        wp_add_inline_script( 'delipress-optin', "
            function delipressLoadOptin(){
                require('javascripts/optins/BaseOptin');
            }

            window.addEventListener ? 
                window.addEventListener('load',delipressLoadOptin,false) : 
                window.attachEvent && window.attachEvent('onload', delipressLoadOptin);
        " );
       
        wp_localize_script('delipress-optin', 'ajaxurl', admin_url( 'admin-ajax.php' ) );
    }

    public static function isOptinScriptLoaded(){
        return self::$loaded;
    }
    

    /**
     * @filter DELIPRESS_SLUG . "_list_providers"
     *
     * @return void
     */
    public static function getListOptins(){

        return apply_filters(DELIPRESS_SLUG . "_list_providers",
            array(
                self::POPUP       => array(
                    "label"        => esc_html__("Popup",'delipress'),
                    "key"          => self::POPUP,
                    "description"  => __('Allows you to display beautifully designed popups at the right time. <strong>You</strong> decide when they appear — delay, scroll, click...', 'delipress'),
                    "is_active"    => true,
                    "third_part"   => false,
                    "is_premium"   => true,
                    "has_behavior" => true,
                    "url_how_work" => "",
                    "form_post_authorize" => array(
                        "number_days_session"        => "intval",
                        "range_session"              => "sanitize_text_field",
                        "auto_close_after_subscribe" => "boolval",
                        "hide_on_mobile"             => "boolval",
                        "trigger_after_time_delay"   => "boolval",
                        "after_time_delay"           => "intval",
                        "trigger_after_scrolling"    => "boolval",
                        "after_scrolling_percent"    => "intval",
                        "exit_intent"                => "boolval",
                        "display_pages"              => "checkDisplayPages"

                    )
                ),
                self::SMARTBAR    => array(
                    "label"        => esc_html__("Smart Bar",'delipress'),
                    "key"          => self::SMARTBAR,
                    "description"  => esc_html__('A fixed bar at the top or bottom of the screen.', 'delipress'),
                    "is_active"    => false,
                    "is_premium"   => true,
                    "third_part"   => false,
                    "has_behavior" => true,
                    "url_how_work" => "",
                ),
                self::FLY         => array(
                    "label"        => esc_html__("Fly in",'delipress'),
                    "key"          => self::FLY,
                    "description"  => esc_html__('A box in the corner that appears after a while or when user scrolls.', 'delipress'),
                    "is_premium"   => true,
                    "is_active"    => true,
                    "third_part"   => false,
                    "has_behavior" => true,
                    "url_how_work" => "",
                    "form_post_authorize" => array(
                        "number_days_session"        => "intval",
                        "range_session"              => "sanitize_text_field",
                        "auto_close_after_subscribe" => "boolval",
                        "hide_on_mobile"             => "boolval",
                        "trigger_after_time_delay"   => "boolval",
                        "after_time_delay"           => "intval",
                        "trigger_after_scrolling"    => "boolval",
                        "after_scrolling_percent"    => "intval",
                        "exit_intent"                => "boolval",
                        "display_pages"              => "checkDisplayPages"
                    )
                ),
                self::WIDGET      => array(
                    "label"        => esc_html__("Widget", 'delipress'),
                    "key"          => self::WIDGET,
                    "description"  => esc_html__('Define an Opt-In form directly in a widget area of your choice.', 'delipress'),
                    "is_active"    => true,
                    "is_premium"   => false,
                    "third_part"   => false,
                    "has_behavior" => false,
                    "url_how_work" => "",
                ),
                self::AFTER_CONTENT  => array(
                    "label"        => esc_html__("After content", 'delipress'),
                    "key"          => self::AFTER_CONTENT,
                    "description"  => esc_html__('Appears after pages and/or posts content.', 'delipress'),
                    "is_active"    => true,
                    "is_premium"   => true,
                    "third_part"   => false,
                    "has_behavior" => true,
                    "url_how_work" => "",
                    "form_post_authorize" => array(
                        "number_days_session"        => "intval",
                        "range_session"              => "sanitize_text_field",
                        "auto_close_after_subscribe" => "boolval",
                        "hide_on_mobile"             => "boolval",
                        "display_pages"              => "checkDisplayPages"
                    )
                ),
                self::LOCKED      => array(
                    "label"        => esc_html__("Locked content", 'delipress'),
                    "key"          => self::LOCKED,
                    "description"  => esc_html__('The user must give his email to access a content.', 'delipress'),
                    "is_active"    => false,
                    "is_premium"   => true,
                    "third_part"   => false,
                    "has_behavior" => false,
                    "url_how_work" => "",
                ),
                self::WOOCOMMERCE_ORDER   => array(
                    "label"        => esc_html__("Third   Party Integration", 'delipress'),
                    "key"          => self::WOOCOMMERCE_ORDER,
                    "description"  => esc_html__('Contact Form  7, Gravity Form, WooCommerce...', 'delipress'),
                    "is_active"    => false,
                    "is_premium"   => true,
                    "has_behavior" => false,
                    "third_part"   => true,
                    "url_how_work" => "",
                ),
                self::SHORTCODE   => array(
                    "label"        => esc_html__("Shortcode", 'delipress'),
                    "key"          => self::SHORTCODE,
                    "description"  => esc_html__('Place it wherever you want (for developers).', 'delipress'),
                    "is_active"    => true,
                    "is_premium"   => false,
                    "has_behavior" => false,
                    "third_part"   => false,
                    "url_how_work" => "",
                )
            )
        );
 
    }

    /**
     *
     * @param string $optin
     * @return array
     */
    public static function getFormPostAuthorize($optin){
        $optin = self::getOptinByKey($optin);

        if(!$optin){
            return null;
        }

        if(!isset($optin["form_post_authorize"])){
            return array();
        }

        return $optin["form_post_authorize"];
    }

    /**
     * @param string $optin
     * @return array
     */
    public static function getOptinByKey($optin){
        $optins = self::getListOptins();
        if(
            !array_key_exists($optin, $optins )
        ){
            return null;
        }

        return $optins[$optin];
    }

    /**
     * @param string $optin
     * @return bool
     */
    protected static function verifyOptin($optin){

        $optins = self::getListOptins();
        if(
            !array_key_exists($optin, $optins )
        ){
            wp_redirect(admin_url());
            die;
        }

        return true;

    }


}
