<?php

namespace Delipress\WordPress\Helpers;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

/**
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
abstract class ProviderHelper{

    const MAILJET         = "mailjet";
    const SENDGRID        = "sendgrid";
    const MAILCHIMP       = "mailchimp";
    const SENDINBLUE      = "sendinblue";

    protected static $providerUrl = null;

    protected static $providerPost = null;

    public static function getListProviders(){

        return apply_filters(DELIPRESS_SLUG . "_list_providers",
            array(
                self::MAILCHIMP => array(
                   "label"        => "Mailchimp",
                   "key"          => self::MAILCHIMP,
                   "hook"         => __("Free for 2000 subscribers.", "delipress"),
                   "description"  => "",
                   "img_src"      => DELIPRESS_PATH_PUBLIC_IMG . "/providers/mailchimp.png",
                   "active"       => true,
                   "sticky"       => true,
                   "url"          => "https://mailchimp.com/",
                   "url_pricing"  => "https://mailchimp.com/pricing/",
                   "url_register" => "https://login.mailchimp.com/signup/",
                   "url_api_key"  => "https://login.mailchimp.com/?referrer=%2Faccount%2Fapi%2F",
                   "why_choose"   => "",
                   "webhooks"     => array(
                       "subscribe",
                       "unsubscribe"
                   ),
                   "webhooks_scope"  => "list"
               ),
                self::MAILJET => array(
                    "label"        => "Mailjet",
                    "key"          => self::MAILJET,
                    "hook"         => __("Free for 6000 emails per month.", "delipress"),
                    "description"  => "",
                    "img_src"      => DELIPRESS_PATH_PUBLIC_IMG . "/providers/mailjet.png",
                    "active"       => true,
                    "sticky"       => false,
                    "url"          => "https://www.mailjet.com/?aff=delipress",
                    "url_pricing"  => "https://www.mailjet.com/pricing_v3?aff=delipress",
                    "url_register" => "https://www.mailjet.com/?aff=delipress",
                    "why_choose"   => "",
                    "webhooks"     => array(
                        "unsubscribe"
                    ),
                    "webhooks_scope" => "all"
                ),
                 self::SENDGRID => array(
                    "label"        => "Sendgrid",
                    "key"          => self::SENDGRID,
                    "description"  => "",
                    "img_src"      => DELIPRESS_PATH_PUBLIC_IMG . "/providers/sendgrid.png",
                    "active"       => false,
                    "sticky"       => false,
                    "url"          => "https://sendgrid.com/",
                    "url_pricing"  => "https://sendgrid.com/pricing/",
                    "url_register" => "https://sendgrid.com/pricing/",
                    "why_choose"   => "",
                    "webhooks"     => array(
                        "subscribe",
                        "unsubscribe"
                    ),
                    "webhooks_scope"  => "list"
                ),
            )
        );

    }

    /**
     * @param string $provider
     * @return array
     */
    public static function getProviderByKey($provider){
        $providers = self::getListProviders();
        if(
            !array_key_exists($provider, $providers )
        ){
            return null;
        }

        return $providers[$provider];
    }

    /**
     * @param string $provider
     * @return bool
     */
    protected static function verifyProvider($provider){

        $providers = self::getListProviders();
        if(
            !array_key_exists($provider, $providers )
        ){
            wp_redirect(admin_url());
            die;
        }

        return true;

    }

    /**
     * @return array
     */
    public static function getProviderFromUrl(){

        if(self::$providerUrl){
            return self::$providerUrl;
        }

        if(isset($_GET["provider"])){
            if(self::verifyProvider($_GET["provider"])){
                $providers = self::getListProviders();

                self::$providerUrl = $providers[$_GET["provider"]];
            }
        }

        return self::$providerUrl;
    }

    /**
     * @return array
     */
    public static function getProviderFromPostRequest(){
        if(self::$providerPost){
            return self::$providerPost;
        }

        if(isset($_POST["provider"])){
            if(self::verifyProvider($_POST["provider"])){
                $providers = self::getListProviders();
                self::$providerPost = $providers[$_POST["provider"]];
            }
        }

        return self::$providerPost;
    }
}
