<?php

namespace Delipress\WordPress\Models\AbstractModel;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Services\Table\TableServices;

use Delipress\WordPress\Models\InterfaceModel\ProviderImportInterface;
use Delipress\WordPress\Models\AbstractModel\AbstractProviderSettings;
use Delipress\WordPress\Models\ListModel;

use Delipress\WordPress\Traits\PrepareParams;
use Delipress\WordPress\Async\ExportToProviderBackgroundProcess;




/**
 * AbstractExportToProvider
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
abstract class AbstractExportToProvider extends AbstractProviderSettings implements ProviderImportInterface {

    use PrepareParams;

    protected $fieldsPosts = array(
        "lists"         => "",
    );

    protected $fieldsRequired = array(
        "lists",
    );

    protected $providerApi = null;

    protected $range = 150;

    /**
     *
     * @param ExportToProviderBackgroundProcess $exportToProviderBackgroundProcess
     * @return AbstractExportToProvider
     */
    public function setBackgroundProcess($exportToProviderBackgroundProcess){
        $this->exportToProviderBackgroundProcess = $exportToProviderBackgroundProcess;
        return $this;
    }

    abstract protected function getIdFromListResult($list);

    /**
     * @return void
     */
    public function exportListsToProvider(){

        $response = $this->prepareListsForBackgroundProcess();

        if(!$response["success"]){
            return;
        }
        
        if(!isset($response["results"]) || empty($response["results"])) {
            return;
        }

        foreach($response["results"] as $key => $list){
            $this->exportToProviderBackgroundProcess->push_to_queue($list);
        }

		$this->exportToProviderBackgroundProcess->save()->dispatch();

    }

    /**
     *
     * @param ListModel $list
     * @return array
     */
    protected function prepareListBackgroundProcess(ListModel $listModel){

        $range              = apply_filters(DELIPRESS_SLUG . "_range_" . $this->provider["key"] . "_export", $this->range);
        $prepareExportLists = array();
        $id                 = $listModel->getId();

        if($id){
            $totalSubscriberExport = $listModel->countSubscribers();
            $countCall             = ceil($totalSubscriberExport /  $range);

            for ($i=1; $i <= $countCall; $i++) {
                $prepareExportLists[] = array(
                    "provider"          => $this->provider["key"],
                    "page"              => $i,
                    "total"             => $countCall,
                    "limit"             => $range,
                    "list_id"           => $id,
                );
            }
        }


        return array(
            "success" => true,
            "results" => $prepareExportLists
        );
    }

    /**
     *
     * @param array $params
     * @return array
     */
    protected function prepareListsBackgroundProcess($params){

        $prepareExportLists = array();


        foreach($params["lists"] as $key => $listId){
            $listModel = new ListModel();
            $listModel->setListByTermId($listId);

            $prepareExportLists = $this->prepareListBackgroundProcess($listModel);
        }


        return array(
            "success" => true,
            "results" => $prepareExportLists["results"]
        );
    }

    /**
     * @param ListModel $list
     */
    public function prepareListsForBackgroundProcessWithList(ListModel $list){
        $params["lists"][] = $list->getId();

        $response = $this->prepareListsBackgroundProcess($params);

        foreach($response["results"] as $key => $list){
            $this->exportToProviderBackgroundProcess->push_to_queue($list);
        }

		$this->exportToProviderBackgroundProcess->save()->dispatch();
    }

    /**
     * Prepare Export lists for background process
     * USE ONLY FOR EXPORT
     *
     * @filter DELIPRESS_SLUG . "_range_" . $this->provider["key"] . "_export"
     *
     * @return array
     */
    public function prepareListsForBackgroundProcess(){

        $params = $this->getPostParams("fields");

        if(!empty($this->missingParameters)){
            return array(
                "success" => false,
                "results" => array()
            );
        }

        return $this->prepareListsBackgroundProcess($params);


    }

    /**
     *
     * @param ListModel $list
     * @param int $offset
     * @param int $limit
     * @return void
     */
    public function exportListContacts(ListModel $list, $page, $limit){

        $listSubscriberTableServices = TableServices::getTable("ListSubscriberTableServices");

        $provider                    = $this->optionServices->getProvider();
        $providerMD5                 = $this->optionServices->getMd5Provider();

        $synchronizeWithProvider     = $list->isSynchronizeWithProvider($provider["key"], $providerMD5);

        $response = array(
            "success" => true
        );
        if(!$synchronizeWithProvider){
            $response       = $this->synchronizeListServices->createListSynchronize($list);
            if($response["success"]){
                $idListProvider = $this->getIdFromListResult($response["results"]);
            }
        }
        else{
            $idListProvider = $list->getProviderId(false);
        }

        if($response["success"] || $synchronizeWithProvider){
            $subscribers = TableServices::getTable("ListSubscriberTableServices")->getSubscribers(
                array(
                    "selects" => array(
                        "subscriber_id"
                    ),
                    "links" => array(
                        "subscribers" => array(
                            "selects" => array(
                                "email"
                            )
                        )
                    ),
                    "query" => array(
                        array(
                            "field"    => "status",
                            "operator" => "=",
                            "value"    => "subscribe"
                        ),
                         array(
                             "field"    => "term_taxonomy_id",
                             "operator" => "=",
                             "value"    => $list->getId()
                         )
                    )
                ),
                $page,
                $limit
            );

            $params = array();
            foreach($subscribers as $key => $subscriber){
                $params[$key]["email"] = $subscriber->email;
            }

            $response       = $this->providerApi->createSubscribersOnList($idListProvider, $params);

        }

    }

    /**
     *
     * @param ListModel $list
     * @return void
     */
    public function verifySynchronizeList(ListModel $list){

        $providerId = $list->getProviderId();

        if(!$providerId){
            return array(
                "success" => false
            );
        }

        $response = $this->providerApi
                         ->setSafeError(true)
                         ->getList($providerId);

        if(!$response["success"]){
            return array(
                "success" => false
            );
        }

        return array(
            "success" => true
        );

    }

}
