<?php

namespace Delipress\WordPress\Models\AbstractModel;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\MediatorServicesInterface;
use Delipress\WordPress\Helpers\ProviderHelper;

/**
 * AbstractProviderSettings
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
abstract class AbstractProviderSettings implements MediatorServicesInterface {

    /**
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){
        $this->optionServices          = $services["OptionServices"];
        $this->synchronizeListServices = $services["SynchronizeListServices"];
    }

    /**
     * 
     * @return array
     */
    public function getOptions(){
        if($this->options === null){
            $this->options = $this->optionServices->getOptions();
        }

        return $this->options;
    }


    /**
     * @param Object $providerApi
     * @return ObjectSettings
     */
    public function setApi($providerApi){
        $this->providerApi = $providerApi;

        return $this;
    }

    public function getApi(){
        return $this->providerApi;
    }


    /**
     * @param Object $providerWebhook
     * @return ObjectSettings
     */
    public function setProviderWebhook($providerWebhook){
        $this->providerWebhook = $providerWebhook;

        return $this;
    }

    /**
     * 
     * @param array $options
     * @return AbstractProviderSettings
     */
    public function createClientApi($options){
        switch($this->provider){
            case ProviderHelper::MAILCHIMP:
                $this->providerApi->createClient($options["api_key_mailchimp"]);
                break;
            case ProviderHelper::MAILJET:
                $this->providerApi->createClient($options["client_id"], $options["client_secret"]);
                break;
        }

        return $this;
    }


    /**
     * @param string $provider
     * 
     * @return array
     */
    public function getUserInfo(){

        $response = $this->providerApi->getUser();
        
        $options  = array();

        if($response["success"]){
            switch($this->provider){
                case ProviderHelper::MAILJET:
                    $options = array(
                        "options" => array(
                            "from_to" => $response["results"][0]["Email"]
                        )
                    );
                    break;
                case ProviderHelper::MAILCHIMP:
                    $options = array(
                        "options" => array(
                            "from_to"  => $response["results"]["email"],
                            "reply_to" => $response["results"]["email"]
                        )
                    );
                    break;
            }
        }

        return $options;
    }

}


