<?php

namespace Delipress\WordPress\Models;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Helpers\TaxonomyHelper;
use Delipress\WordPress\Helpers\PostTypeHelper;
use Delipress\WordPress\Helpers\ColorHelper;

use Delipress\WordPress\Models\AbstractModel\AbstractModelTerm;
use Delipress\WordPress\Models\SubscriberModel;

use Delipress\WordPress\Services\Table\TableServices;

/**
 * ListModel
 *
 * @version 1.0.0
 * @since 1.0.0
 */
class ListModel extends AbstractModelTerm{

    public function setListByTermId($id){
        $this->object = get_term($id, TaxonomyHelper::TAXO_LIST);

        if(is_wp_error($this->object)){
            return $this->object = null;
        }

        return $this;
    }

    public function setList($list){
        $this->object = $list;
        return $this;
    }

    /**
     *
     * @return string
     */
    public function countSubscribers(){
        if( property_exists( $this, "countSubscribers" ) ){
            return $this->countSubscribers;
        }

        $this->countSubscribers = TableServices::getTable("ListSubscriberTableServices")->countListSubscribers($this->getId());

        return $this->countSubscribers;

    }

    /**
     * @return boolean
     */
    public function isConnector(){
        global $delipressPlugin;

        $isConnector = false;
        $connectors = $delipressPlugin->getService("OptionServices")->getConnectors();
        foreach($connectors as $key => $connector){
            if(isset($connector["list_id"]) && $connector["list_id"] == $this->getId()){
                $isConnector = true;
                break;
            }
        }

        return $isConnector;
    }

    /**
     *
     * @return boolean
     */
    public function synchronizeInWork(){

        $transient = get_transient("delipress_sync_import_background");

        if(!$transient){
            $transient = get_transient("delipress_sync_export_background");
        }

        if(!$transient){
            $transient = get_transient(DELIPRESS_SLUG . "_save_one_item_import_background_file", false);
            if($transient){
                $id = $this->getId();
                if($id === $transient["list_id"]){
                    return true;
                }

                return false;
            }

        }

        if(!$transient){
            return false;
        }

        $id = $this->getId();
        if(!array_key_exists($id, $transient)){
            return false;
        }

        return ($transient[$id]) ? true : false;
    }



    /**
     *
     * @param boolean $withCache
     * @return array
     */
    public function getAllEmailSubscribers($withCache = true){
        if(!$this->object){
            return "";
        }

        if( property_exists( $this, "emailSubscribers" ) && $withCache){
            return $this->emailSubscribers;
        }

        $this->emailSubscribers = TableServices::getTable("ListSubscriberTableServices")->getEmailListSubscribers($this->getId());

        return $this->emailSubscribers;
    }

    /**
     *
     * @return array
     */
    public function getOptins(){
        return get_posts(
            array(
                'post_type' => PostTypeHelper::CPT_OPTINFORMS,
                'numberposts' => -1,
                'tax_query' => array(
                    array(
                        'taxonomy' => TaxonomyHelper::TAXO_LIST,
                        'field' => 'id',
                        'terms' => $this->getId(),
                    )
                )
            )
        );
    }


    /**
     * @return int
     */
    public function getCountOptins(){
        $optins = $this->getOptins();
        if(!$optins){
            return 0;
        }

        return count($optins);
    }

    /**
     *
     * @param int $nbPerPage
     * @return Array SubscriberModel
     */
    public function getSubscribers($page = 1, $limit = 20){
        if(!$this->object){
            return "";
        }

        if( property_exists( $this, "subscribers" ) ) {
            return $this->subscribers;
        }

        $args = array(
            "selects" => "*",
            "query" => array(
                array(
                    "field"    => "term_taxonomy_id",
                    "operator" => "=",
                    "value"    => $this->getId()
                )
            )
        );

        $subscribers = TableServices::getTable("ListSubscriberTableServices")->getSubscribers(
            $args,
            $page,
            $limit
        );

        foreach($subscribers as $key => $value){
            $subscriber = new SubscriberModel();
            $subscriber->setSubscriberById($value->subscriber_id);
            $subscriber->setListConnect($value);
            $subscribers[$key] = $subscriber;
        }

        $this->subscribers = $subscribers;

        return $this->subscribers;
    }

    /**
     *
     * @param boolean $withCache
     * @return string
     */
    public function getColor($withCache = true){
        $value  = $this->getTermMeta("color", TaxonomyHelper::META_LIST_COLOR, true, $withCache);
        $colors = ColorHelper::getColors();
        return ($value) ? $value : $colors[0];
    }

    /**
     *
     * @param boolean $withCache
     * @return string
     */
    protected function getMetaProvider($withCache = true){
        return $this->getTermMeta("metaProvider", TaxonomyHelper::META_LIST_ID_PROVIDER, true, $withCache);
    }

    /**
     *
     * @param boolean $withCache
     * @return string
     */
    public function getProvider($withCache = true){
        $getMetaProvider = $this->getMetaProvider($withCache);
        if(!$getMetaProvider){
            return null;
        }

        $metaProvider = explode("_", $getMetaProvider);

        return $metaProvider[0];

    }

    /**
     *
     * @param boolean $withCache
     * @return string
     */
    public function getProviderId($withCache = true){
        $getMetaProvider = $this->getMetaProvider($withCache);
        if(!$getMetaProvider){
            return null;
        }

        $metaProvider = explode("_", $getMetaProvider);
        return $metaProvider[1];
    }

    public function getApiKeyMD5(){
        return $this->getTermMeta("apiKeyMD5", TaxonomyHelper::META_LIST_API_KEY_MD5, true);
    }

    /**
     *
     * @param string $provider
     * @return bool
     */
    public function isSynchronizeWithProvider($provider, $md5Provider){
        return $provider === $this->getProvider() && $md5Provider === $this->getApiKeyMD5();
    }

    /**
     * @return bool
     */
    public function isSynchronize(){
        $provider = $this->getProvider();
        return !empty($provider);
    }

}
