<?php

namespace Delipress\WordPress\Models;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Helpers\PageAdminHelper;
use Delipress\WordPress\Helpers\PostTypeHelper;
use Delipress\WordPress\Helpers\SourceSubscriberHelper;
use Delipress\WordPress\Helpers\TaxonomyHelper;
use Delipress\WordPress\Helpers\StatusHelper;

use Delipress\WordPress\Models\AbstractModel\AbstractModel;
use Delipress\WordPress\Models\OptinModel;
use Delipress\WordPress\Services\Table\TableServices;


/**
 * SubscriberModel
 *
 * @version 1.0.0
 * @since 1.0.0
 */
class SubscriberModel extends AbstractModel {

    /**
     * 
     * @param int $id
     * @return SubscriberModel
     */
    public function setSubscriberById($id){
        $this->object = TableServices::getTable("SubscriberTableServices")->getSubscriberById($id);
        return $this;
    }

    /**
     * 
     * @param array $listSubscriber
     * @return SubscriberModel
     */
    public function setListConnect($listSubscriber){
        $this->listConnect = $listSubscriber;
        return $this;
    }

    /**
     * 
     * @param array $subscriber
     * @return SubscriberModel
     */
    public function setSubscriber($subscriber){
        $this->object = $subscriber;
        return $this;
    }

    /**
     * @return string
     */
    public function getEmail(){
        return esc_html($this->getValue("email") );
    }

    /**
     * @return string
     */
    public function getFirstName(){
        return esc_html($this->getValue("first_name") );
    }

    /**
     * @return string
     */
    public function getLastName(){
        return esc_html( $this->getValue("last_name") );
    }

    public function getIsSubscribe(){
        $status = $this->getStatusListConnect();

        if($status === StatusHelper::UNSUBSCRIBE){
            return false;
        }

        return true;
    }


    public function getStatus($str = false){
        $status = $this->getStatusListConnect();

        if(!$str){
            return $status;
        }

        if($status === StatusHelper::UNSUBSCRIBE){
            return esc_html__("Unsubscribed", "delipress");
        }

        if($status === StatusHelper::PENDING){
            return esc_html__("Pending", "delipress");
        }

        return esc_html__("Subscribed","delipress");
    }

    /**
     * @return string
     */
    public function getSource(){
        $source = $this->getSourceListConnect();
        
        $existSource = SourceSubscriberHelper::getSourceSubscriber($source);
        if($existSource){
            return $existSource;
        }

        $optin = new OptinModel();
        $optin->setOptinById($source);

        return esc_html( $optin->getTitle() );

    }

    /**
     * 
     * @param int $listId
     * @return bool
     */
    public function isSourceOptinByListId($listId){
        $source = $this->getSourceListConnect();
        if(is_int($source)){
            return true;
        }

        return false;
    }

    public function getSourceListConnect(){
        if(!$this->listConnect){
            return null;
        }

        if(!property_exists($this->listConnect, "source")){
            return null;
        }

        return $this->listConnect->source;
    }

    public function getStatusListConnect(){
        if(!$this->listConnect){
            return null;
        }

        if(!property_exists($this->listConnect, "status")){
            return null;
        }

        return $this->listConnect->status;
    }

    /**
     * @return string
     */
    public function getProvider(){
        if(property_exists($this, "provider")){
            return $this->provider->provider;
        }

        $result = TableServices::getTable("ListSubscriberTableServices")->getListSubscriber(
            array(
                "selects" => array(
                    "provider"
                ),
                "query" => array(
                    array(
                        "field"    => "subscriber_id",
                        "value"    => $this->getId(),
                        "operator" => "=",
                        "type"     => "int"
                    )
                )
            )
        );

        if(isset($result["provider"])){
            $this->provider = $result["provider"];
        }

        return $this->provider;

    }

    /**
     * @return string
     */
    public function getProviderId(){

        if(property_exists($this, "provider_id")){
            return $this->provider_id;
        }
        
        if(
            property_exists($this, "object") && 
            is_array($this->object) && 
            isset($this->object["provider_id"]) 
        ){
            return $this->object["provider_id"];
        }

        $result = TableServices::getTable("ListSubscriberTableServices")->getListSubscriber(
            array(
                "selects" => array(
                    "provider_id"
                ),
                "query" => array(
                    array(
                        "field"    => "subscriber_id",
                        "value"    => $this->getId(),
                        "operator" => "=",
                        "type"     => "int"
                    )
                )
            )
        );

        if(isset($result["provider_id"])){
            $this->provider_id = $result["provider_id"];
        }

        return $this->provider_id;
    }


     /**
     * @return string
     */
    public function getProviderIdByListId($listId){

        if(property_exists($this, "list_subscriber_provider_id")){
            return $this->list_subscriber_provider_id;
        }
        
        if(
            property_exists($this, "object") && 
            is_array($this->object) && 
            isset($this->object["list_subscriber_provider_id"]) 
        ){
            return $this->object["list_subscriber_provider_id"];
        }

        $result = TableServices::getTable("ListSubscriberTableServices")->getListSubscriber(
            array(
                "selects" => array(
                    "provider_id"
                ),
                "query" => array(
                    array(
                        "field"    => "subscriber_id",
                        "value"    => $this->getId(),
                        "operator" => "=",
                        "type"     => "int"
                    ),
                    array(
                        "field"    => "term_taxonomy_id",
                        "value"    => $listId,
                        "operator" => "=",
                        "type"     => "int"
                    )
                )
            )
        );

        if(isset($result["provider_id"])){
            $this->list_subscriber_provider_id = $result["provider_id"];
        }
        else{
            return null;
        }

        return $this->list_subscriber_provider_id;
    }

    /**
     * @return string
     */
    public function getIsConfirmed(){
        return $this->getValue("is_confirmed");
    }

    /**
     * @return string
     */
    public function getTokenUnsubscribe($withCache = true){
        if($withCache){
            return $this->getValue("token_unsubscribe");
        }

        $id = $this->getId();

        $this->object = TableServices::getTable("SubscriberTableServices")->getSubscriberById($id);

        return esc_html( $this->getValue("token_unsubscribe") );

        
    }

    /**
     * @return string
     */
    public function getSalt(){
        return esc_html( $this->getValue("salt") );
    }

    /**
     * @return string
     */
    public function getOnListCreatedAt($listId){
        if(!$this->object){
            return "";
        }   

        $result = TableServices::getTable("ListSubscriberTableServices")->getListSubscriber(
            array(
                "selects" => array(
                    "created_at"
                ),
                "query" => array(
                    array(
                        "field"    => "subscriber_id",
                        "value"    => $this->getId(),
                        "operator" => "=",
                        "type"     => "int"
                    ),
                    array(
                        "field"    => "term_taxonomy_id",
                        "value"    => $listId,
                        "operator" => "=",
                        "type"     => "int"
                    )
                )
            )
        );

        if(!$result || empty($result)){
            return null;
        }

        return  date_i18n( get_option( 'date_format' ), strtotime( $result["created_at"] ) ); 
    }

}
