<?php

namespace Delipress\WordPress\Optin;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\HooksFrontInterface;
use DeliSkypress\Models\ContainerInterface;
use DeliSkypress\WordPress\Actions\AbstractHook;

use Delipress\WordPress\Helpers\OptinHelper;

/**
 * BaseOptin
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class BaseOptin extends AbstractHook implements HooksFrontInterface{

    protected $typeOptin = null;

    /**
     *  @param ContainerInterface $containerServices
     */
    public function setContainerServices(ContainerInterface $containerServices){
        $this->optinServices = $containerServices->getService("OptinServices");
    }


    /**
     * @see HooksFrontInterface
     */
    public function hooks(){
        $this->prepareOptin();
    }

    public function getOptins(){
        return array();
    }

    public function prepareOptin(){

        $this->optins = $this->getOptins();
        
        if(empty($this->optins)){
            return;
        }
        
        add_action("wp_footer", array($this, "delipressOptin"));
    
    }

    /**
     * @see wp_footer
     */
    public function delipressOptin(){
        
        $loop = $this->getLoop();

        foreach($this->optins as $key => $optin){

            $behavior      = unserialize( $optin["behavior"] );

            if(!isset($behavior["display_pages"])){
                return;
            }

            if(
                array_key_exists("everything", $behavior["display_pages"]) && 
                $behavior["display_pages"]["everything"]["all"] 
            ){
                $this->printOptin($key, $optin, $this->typeOptin);
                return;
            }

            switch($loop){
                case "homepage":
                case "blogpage":
                case "archives":
                    $behaviorPages = $behavior["display_pages"][$loop];

                    if(array_key_exists("all", $behaviorPages) && $behaviorPages["all"]){
                        $this->printOptin($key, $optin, $this->typeOptin);
                        return;
                    }
                    break;
                case "taxonomies":
                    if(array_key_exists("categories", $behavior["display_pages"]) && $behavior["display_pages"]["categories"]["all"] ){
                        $this->printOptin($key, $optin, $this->typeOptin);
                        return;
                    }

                    $this->printOnTerm($key, $optin);
                    break;
                case "page":
                    $this->printOnPage($key, $optin);
                    break;
                case "single":                
                    $this->printOnSingle($key, $optin);
                    break;
            }
            
        }

    }


    /**
     *
     * @return string
     */
    protected function getLoop(){
        global $wp_query;

        $loop = 'notfound';

        if ( $wp_query->is_page ) {
            if(is_front_page()){
                $loop = "homepage";
            }
            else if(is_home()){
                $loop = "blogpage";
            }
            else {
                $loop = "page";
            }
        } elseif ( $wp_query->is_home ) {
            $loop = 'homepage';
        } elseif ( $wp_query->is_single ) {
            $loop = ( $wp_query->is_attachment ) ? 'attachment' : 'single';
        } elseif ( $wp_query->is_category || $wp_query->is_tag || $wp_query->is_tax) {
            $loop = 'taxonomies';
        } elseif ( $wp_query->is_archive ) {
            $loop = 'archives';
        }

        return $loop;
    }

    /**
     *
     * @param int $key
     * @param array $optin
     * @return void
     */
    protected function printOnTerm($key, $optin){
        global $wp_query;
        
        if(!$wp_query->queried_object){
            return;
        }

        $termId      = $wp_query->queried_object->term_id;
        $taxo        = $wp_query->queried_object->taxonomy;
        $behavior    = unserialize( $optin["behavior"] );

        if(!array_key_exists($taxo, $behavior["display_pages"])){
            return;
        }

        if(
             array_key_exists("categories", $behavior["display_pages"]) && 
            array_key_exists("all", $behavior["display_pages"]["categories"]) && 
            $behavior["display_pages"]["categories"]["all"]    
        ){
            $this->printOptin($key, $optin, $this->typeOptin);
            return;
        }


        $behaviorPages = $behavior["display_pages"][$taxo];

        if(array_key_exists("choice_pages", $behaviorPages) && in_array($termId, $behaviorPages["choice_pages"])){
            $this->printOptin($key, $optin, $this->typeOptin);
            return;
        }
    }

    /**
     *
     * @param string $postType
     * @param int $key
     * @param array $optin
     */
    protected function printOnPostType($postType, $key, $optin){
        global $wp_query;
        
        $postId      = $wp_query->post->ID;
        $behavior    = unserialize( $optin["behavior"] );
        if(!array_key_exists($postType, $behavior["display_pages"])){
            return;
        }
        

        if(
            array_key_exists("posttypes", $behavior["display_pages"]) && 
            array_key_exists("all", $behavior["display_pages"]["posttypes"]) && 
            $behavior["display_pages"]["posttypes"]["all"]    
        ){
            $this->printOptin($key, $optin, $this->typeOptin);
            return;
        }

        $behaviorPages = $behavior["display_pages"][$postType];

        if(
            array_key_exists("all", $behaviorPages) && 
            $behaviorPages["all"]    
        ){
           $this->printOptin($key, $optin, $this->typeOptin);
           return;
        }
        

        if(array_key_exists("choice_pages", $behaviorPages) && in_array($postId, $behaviorPages["choice_pages"])){
            $this->printOptin($key, $optin, $this->typeOptin);
            return;
        }
    }

    /**
     *
     * @param string $key
     * @param array $optin
     * @return void
     */
    protected function printOnPage($key, $optin){
        
       $this->printOnPostType("page", $key, $optin);
    }

    /**
     *
     * @param string $key
     * @param array $optin
     * @return void
     */
    protected function printOnSingle($key, $optin){
        global $wp_query;
        $this->printOnPostType($wp_query->post->post_type, $key, $optin);

    }

    /**
     *
     * @param int $id
     * @param array $optin
     * @param string $type
     */
    protected function printOptin($id, $optin, $type){

        $isLoadedScript = OptinHelper::isOptinScriptLoaded();
        
        if(!$isLoadedScript){
            OptinHelper::loadOptinScript(true);
        }

        echo sprintf(
            "<div 
                id='DELI-%s-%s' 
                class='delipress-optin' 
                data-config='%s' 
                data-id='%s' 
                data-type='%s'
                data-behavior='%s'
            ></div>",
            $type,
            $id,
            esc_attr($optin["config"]),
            $id,
            $type,
            wp_json_encode(unserialize($optin["behavior"]))
        );

    }
    

}
