<?php

namespace Delipress\WordPress\Services\Campaign;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\ServiceInterface;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Models\CampaignModel;

use Delipress\WordPress\Helpers\ActionHelper;
use Delipress\WordPress\Helpers\AdminNoticesHelper;
use Delipress\WordPress\Helpers\PageAdminHelper;
use Delipress\WordPress\Helpers\PostTypeHelper;
use Delipress\WordPress\Helpers\CodeErrorHelper;


/**
 * SendCampaignServices
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class SendCampaignServices implements ServiceInterface, MediatorServicesInterface{
    
    /**
     * @see MediatorServicesInterface
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){
        $this->providerServices = $services["ProviderServices"];
        $this->optionServices = $services["OptionServices"];

    }

    /**
     * 
     * @action DELIPRESS_SLUG . "_before_send_campaign"
     * @action DELIPRESS_SLUG . "_after_send_campaign"
     * 
     * @param CampaignModel $campaign
     * @return array
     */
    public function sendCampaign(CampaignModel $campaign){
        
        do_action(DELIPRESS_SLUG . "_before_send_campaign", $campaign);
        
        $provider         = $this->optionServices->getProvider();

        $providerApi = $this->providerServices
                            ->getProviderApi($provider["key"]);
        

        $response = $providerApi->sendCampaign($campaign);

        if($response["success"]){
            $args = array(
                'ID'            => $campaign->getId(),
                'post_status'   => "publish"
            );

            $postId =  wp_update_post($args);

            update_post_meta($campaign->getId(), PostTypeHelper::META_CAMPAIGN_IS_SEND, 1);

            AdminNoticesHelper::registerSuccess(
                CodeErrorHelper::ADMIN_NOTICE,
                CodeErrorHelper::getMessage(CodeErrorHelper::SEND_CAMPAIGN_SUCCESS)
            );
        }
        else{
            AdminNoticesHelper::registerError(
                CodeErrorHelper::ADMIN_NOTICE,
                CodeErrorHelper::getMessage(CodeErrorHelper::SEND_CAMPAIGN_ERROR)
            );
        }

        do_action(DELIPRESS_SLUG . "_after_send_campaign", $campaign, $response);

        return $response;
    }

}


