<?php

namespace Delipress\WordPress\Services\Connector;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Models\AbstractModel\AbstractProviderImport;
use Delipress\WordPress\Models\InterfaceModel\ConnectorInterface;
use Delipress\WordPress\Models\ListModel;

use Delipress\WordPress\Helpers\TaxonomyHelper;
use Delipress\WordPress\Helpers\ConnectorHelper;

use Delipress\WordPress\Services\Table\TableServices;

/**
 * AbstractConnectorServices
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
abstract class AbstractConnectorServices extends AbstractProviderImport implements ConnectorInterface, MediatorServicesInterface {

    protected $range = 150;
    
    /**
     * @see MediatorServicesInterface
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){
        parent::setServices($services);
        $this->synchronizeListServices = $services["SynchronizeListServices"];
        $this->deleteListServices      = $services["DeleteListServices"];
        $this->connector               = ConnectorHelper::getConnectorByKey($this->keyConnector);
    }


     /**
     * @see ConnectorInterface
     *
     * @return void
     */
    public function prepareConnector(){
        
        $response = $this->createList();

        if(isset($response["wp_term_error"])){
            return $response;
        }

        $prepareLists = $this->prepareLists($response["results"]["term_id"]);

        $this->prepareBackgroundProcess($prepareLists);

        return $response;

    }

    /**
     * @see ConnectorInterface
     *
     * @return void
     */
    public function removeConnector($listId){

        $removeList = apply_filters(DELIPRESS_SLUG . "_remove_list_connect_" . $this->keyConnector, true );

        if($removeList){
            add_filter(DELIPRESS_SLUG . "_synchronize_delete_list", function(){
                return true;
            });

            $this->removeList($listId);
        }
    }   


    protected function getProvider(){
        return null;
    }
    

    protected function getSource(){
        return $this->keyConnector;
    }
    

     /**
     *
     * @param array $list
     * @return null
     */
    protected function getIdFromListResult($list){
        return null;
    }

    /**
     *
     * @param array $list
     * @return null
     */
    protected function getNameFromListResult($list){
        return null;
    }

    /**
     *
     * @param array $list
     * @return null
     */
    protected function getTotalSubscriberFromListResult($list){
        return null;
    }

    /**
     *
     * @param array $subscriber
     * @return null
     */
    protected function getIdSubscriberFromSubscribersResult($subscriber){
        return null;
    }


    /**
     * Create list connector
     *
     * @return array
     */
    protected function createList(){
        
        $name       = $newName = apply_filters(DELIPRESS_SLUG . "_name_" . $this->connector["key"] . "_connector", $this->connector["label"]);

        $termExist = get_term_by( "name", $name, TaxonomyHelper::TAXO_LIST, ARRAY_A );

        $i       = 1;
        while($termExist){
            $newName = $name . " ($i)";
            $termExist = get_term_by( "name", $newName, TaxonomyHelper::TAXO_LIST, ARRAY_A );
            $i++;
        }

        $term = wp_insert_term(
            $newName,
            TaxonomyHelper::TAXO_LIST
        );

        if(is_wp_error( $term ) ){
            return array(
                "success"       => false,
                "wp_term_error" => true
            );
        }
        
        return array(
            "success" => true,
            "results" => $term   
        );
    }

    /**
     *
     * @param int $idList
     * @return array
     */
    protected function removeList($idList){
        $list = new ListModel();
        $list->setListByTermId($idList);

        return $this->deleteListServices->deleteOneList($list);
    }

}









