<?php

namespace Delipress\WordPress\Services;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\ServiceInterface;
use DeliSkypress\Models\Strategy\AbstractStrategy;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Helpers\ActionHelper;
use Delipress\WordPress\Strategy\ImportJsonStrategy;


/**
 * ImportServices
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class ImportServices extends AbstractStrategy implements ServiceInterface, MediatorServicesInterface {

    /**
     * @see MediatorServicesInterface
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){
        if(!array_key_exists("ListServices", $services)){
            throw new Exception("Miss ListServices");
        }

        $this->listServices = $services["ListServices"];

    }

    public function setFile($file){
        $this->file = $file;
        return $this;
    }

    public function setTypeImport($type){
        $this->type = $type;
        return $this;
    }

    /**
     * @see StrategyInterface
     * @return void
     */
    public function execute(){
        if($this->file === null){
            throw new Exception("No file");
            
        }

        $fileType        = $this->file['import']['type'];
        $fileName        = $this->file['import']['name'];

        $_POST_action    = $_POST['action'];
        $_POST['action'] = 'wp_handle_sideload';

        $strategy = null;
        $mimes    = array();
        switch ($fileType) {
            case 'application/json':
            default:
                $strategy = new ImportJsonStrategy();
                $mimes = array(
                    "mimes" => array(
                        "json" => $fileType
                    )
                );
                break;
        }

        $file            = wp_handle_sideload( $this->file['import'], $mimes);
        
        $_POST['action'] = $_POST_action;
        $data            = file_get_contents( $file['file'] );


        $data = $strategy->setData($data)
                         ->execute();

        switch ($this->type) {
            case ActionHelper::LIST_IMPORT:
                $this->listServices->importLists($data);
                break;
        }

        file_put_contents( $file['file'], '');
        unlink( $file['file'] );

    }

}
