<?php

namespace Delipress\WordPress\Services\Listing;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\ServiceInterface;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Helpers\ProviderHelper;
use Delipress\WordPress\Helpers\TaxonomyHelper;

use Delipress\WordPress\Models\ListModel;


/**
 * SynchronizeListServices
 *
 * @author DeliPress
 * @version 1.0.0
 * @since 1.0.0
 */
class SynchronizeListServices implements ServiceInterface, MediatorServicesInterface {


    /**
     * @see MediatorServicesInterface
     *
     * @param array $services
     * @return void
     */
    public function setServices($services){
        if(!array_key_exists("OptionServices", $services)){
            throw new Exception("Miss OptionServices");
        }
        if(!array_key_exists("ProviderServices", $services)){
            throw new Exception("Miss ProviderServices");
        }

        $this->optionServices   = $services["OptionServices"];
        $this->providerServices = $services["ProviderServices"];

    }

    /**
     *
     * @action DELIPRESS_SLUG . "_before_create_list_synchronize_" . $provider["key"]
     * @action DELIPRESS_SLUG . "_after_create_list_synchronize_" . $provider["key"]
     *
     * @param ListModel $list
     * @return array
     */
    public function createListSynchronize(ListModel $list){
        $provider = $this->optionServices->getProvider();

        if(
            array_key_exists("is_connect", $provider) &&
            $provider["is_connect"]
        ){


            do_action(DELIPRESS_SLUG . "_before_create_list_synchronize", $list);

            $providerMD5 = $this->optionServices->getMd5Provider();

            $response = $this->providerServices
                             ->getProviderApi($provider["key"])
                             ->createList($list);

            if($response["success"]){
                switch($provider["key"]){
                    case ProviderHelper::MAILJET:
                        $idListProvider = $response["results"][0]["ID"];
                        break;
                    case ProviderHelper::MAILCHIMP:
                        $idListProvider = $response["results"]["id"];
                        break;
                    default:
                        $idListProvider = apply_filters(DELIPRESS_SLUG . "_create_list_synchronize_" . $provider["key"], $response);
                        break;
                }

                update_term_meta($list->getId(), TaxonomyHelper::META_LIST_ID_PROVIDER, sprintf("%s_%s", $provider["key"], $idListProvider) );
                update_term_meta($list->getId(), TaxonomyHelper::META_LIST_API_KEY_MD5, $providerMD5 );

                $isLocal = delipress_is_local();

                if(!$isLocal){
                    $this->providerServices
                        ->getProviderWebhook($provider["key"])
                        ->createWebhookOnList($list);
                }
            }
            else{
                return array(
                    "success"  => false,
                    "response" => $response
                );
            }

            do_action(DELIPRESS_SLUG . "_before_create_list_synchronize", $response, $list);

            return $response;
        }

        return array(
            "success" => true
        );
    }

    /**
     *
     * @param ListModel $list
     * @param array $contacts
     * @return void
     */
    public function synchronizeContactsOnList(ListModel $list){
        $provider = $this->optionServices->getProvider();

        if(
            array_key_exists("is_connect", $provider) &&
            $provider["is_connect"]
        ){
             $response = $this->providerServices
                              ->getProviderExport($provider["key"])
                              ->prepareListsForBackgroundProcessWithList($list);

            return $response;
        }

        return array(
            "success" => false
        );
    }

    /**
     *
     * @param ListModel $list
     */
    public function verifySynchronizeList(ListModel $list){

        $provider = $this->optionServices->getProvider();

        if(
            array_key_exists("is_connect", $provider) &&
            $provider["is_connect"]
        ){



            $response = $this->providerServices
                            ->getProviderExport($provider["key"])
                            ->verifySynchronizeList($list);


            if(!$response["success"]){
                $response = $this->createListSynchronize($list);
                if($response["success"]){
                    $this->synchronizeContactsOnList($list);
                }

                return array(
                    "success" => false
                );

            }

            return array(
                "success" => true
            );

        }

        return array(
            "success" => true
        );

    }



}
