<?php

namespace Delipress\WordPress\Services\Provider\Mailchimp;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Models\AbstractModel\AbstractProviderImport;

use Delipress\WordPress\Helpers\ProviderHelper;
use Delipress\WordPress\Helpers\SourceSubscriberHelper;
use Delipress\WordPress\Helpers\StatusHelper;


/**
 * MailchimpImport
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class MailchimpImport extends AbstractProviderImport {

    protected $range = 150;

    protected $callMetaData = false;

    protected $sourceProvider = SourceSubscriberHelper::IMPORT_MAILCHIMP;

    public function __construct(){
        $this->provider = ProviderHelper::getProviderByKey(ProviderHelper::MAILCHIMP);
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $list
     * @return string
     */
    protected function getIdFromListResult($list){
        return $list["id"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $list
     * @return string
     */
    protected function getNameFromListResult($list){
        return $list["name"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $list
     * @return string
     */
    protected function getTotalSubscriberFromListResult($list){
        return (int) $list["stats"]["member_count"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getEmailSubscriberFromSubscribersResult($subscriber){
        return $subscriber["email_address"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getCreatedAtSubscriberFromSubscribersResult($subscriber){
        return new \DateTime($subscriber["timestamp_signup"]);
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getIdSubscriberFromSubscribersResult($subscriber){
        return $subscriber["id"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getFirstNameSubscriberFromSubscribersResult($subscriber){
        return (isset($subscriber["merge_fields"]["FNAME"])) ? $subscriber["merge_fields"]["FNAME"] : "";
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getLastNameSubscriberFromSubscribersResult($subscriber){
        return (isset($subscriber["merge_fields"]["LNAME"])) ? $subscriber["merge_fields"]["LNAME"] : "";
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getIsUnsubscribeFromSubscriberResult($subscriber){
        return ($subscriber["status"] != "subscribe") ? true : false;
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getStatusSubscribeFromSubscriberResult($subscriber){
        switch($subscriber["status"]){
            case "subscribed":
                return StatusHelper::SUBSCRIBE;
            case "unsubscribed":
                return StatusHelper::UNSUBSCRIBE;
            case "pending":
                return StatusHelper::PENDING;
        }
    }

}

