<?php

namespace Delipress\WordPress\Services\Provider\Mailchimp;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Models\AbstractModel\AbstractProviderWebhook;

use Delipress\WordPress\Models\ListModel;

use Delipress\WordPress\Helpers\ProviderHelper;

use DrewM\MailChimp\Webhook;

/**
 * MailchimpWebhook
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class MailchimpWebhook extends AbstractProviderWebhook {

    protected $provider = ProviderHelper::MAILCHIMP;

    /**
     * @filter DELIPRESS_SLUG . "_webhook_on_list_params_" . ProviderHelper::MAILCHIMP
     * 
     * @param ListModel $list
     * @return array
     */
    public function createWebhookOnList(ListModel $list){

        $typeWebhooks = apply_filters(DELIPRESS_SLUG . "_type_webhooks_" . $this->provider, 
            array(
                "subscribe",
                "unsubscribe"
            )
        );

        $webhooksResult = $this->providerApi->listWebhookOnList($list);

        $options = array();

        foreach($typeWebhooks as $key => $webhook){
            $params = array(
                "events"  => array(
                    'subscribe'   => false,
                    'unsubscribe' => false,
                    'profile'     => false,
                    'cleaned'     => false,
                    'upemail'     => false,
                    'campaign'    => false
                ),
                "url"     => "",
                "sources" => array(
                    "user"  => true,
                    "admin" => true,
                    "api"   => true
                )
            );

            $params["events"][$webhook] = true;

            switch($webhook){
                case "subscribe":
                    $params["url"] = $this->webhookServices->getUrlWebhookSubscribe($this->provider);
                    break;
                case "unsubscribe":
                    $params["url"] = $this->webhookServices->getUrlWebhookUnsubscribe($this->provider);
                    break;
            }

            $params = apply_filters(DELIPRESS_SLUG . "_webhook_on_list_params_" . $this->provider, $params);

            $webhookInWork = null;
            if($webhooksResult["success"] && !empty($webhooksResult["results"]) && !empty($webhooksResult["results"]["webhooks"]) ){

                foreach($webhooksResult["results"]["webhooks"] as $keyWH => $valueWebhook){
                    if($valueWebhook["events"][$webhook]){
                        $webhookInWork = $valueWebhook;
                        break;
                    }
                }
            }

            $forceRewriteWebhooks = apply_filters(DELIPRESS_SLUG . "_force_rewrite_webhooks_" . $this->provider, true);

            if($forceRewriteWebhooks && $webhookInWork != null){
                $params["id"] = $webhookInWork["id"];

                $response = $this->providerApi
                                 ->removeWebhookOnList($list, $params);
            }

            $response = $this->providerApi
                             ->createWebhookOnList($list, $params);

            

            if($response["success"]){

                $options[$response["results"]["id"]] = array(
                    "type"         => $webhook,
                    "url"          => $params["url"],
                    "list_id"      => $response["results"]["list_id"],
                    "provider"     => $this->provider
                ); 
            }
        }

        $this->webhookOptionServices
                ->setOptions($options);

    }

    /**
     *
     * @param ListModel $list
     * @return void
     */
    public function removeWebhookOnList(ListModel $list){

    }


    /**
     * @return void
     */
    public function webhookUnsubscribe(){

        Webhook::subscribe('unsubscribe', function($data){
            $list       = $this->listServices->getListByProviderId($this->provider, $data["list_id"]);
            $subscriber = $this->subscriberServices->getSubsriberByEmail($data["email"]);
            
            $this->unsubscribe(
                array(
                    "action"     => (isset($data["action"])) ? $data["action"] : "unsub",
                    "subscriber" => $subscriber,
                    "list"       => $list
                )
            );

        });
    }

    /**
     * @return void
     */
    public function webhookSubscribe(){
        
        
        Webhook::subscribe('subscribe', function($data){

            $list       = $this->listServices->getListByProviderId($this->provider, $data["list_id"]);
            $subscriber = $this->subscriberServices->getSubsriberByEmail($data["email"]);

            $this->subscribe(
                array(
                    "subscriber" => $subscriber,
                    "list"       => $list,
                    "email"      => $data["email"],
                    "first_name" => (isset($data["merges"]["FNAME"])) ? $data["merges"]["FNAME"] : "",
                    "last_name"  => (isset($data["merges"]["LNAME"])) ? $data["merges"]["LNAME"] : "",
                )
            );
            
        });
    }



}

