<?php

namespace Delipress\WordPress\Services\Provider\Mailjet;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Models\AbstractModel\AbstractProviderImport;

use Delipress\WordPress\Helpers\ProviderHelper;
use Delipress\WordPress\Helpers\SourceSubscriberHelper;
use Delipress\WordPress\Helpers\StatusHelper;


/**
 * MailjetImport
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class MailjetImport extends AbstractProviderImport {

    protected $range = 100;

    protected $callMetaData = true;

    protected $sourceProvider = SourceSubscriberHelper::IMPORT_MAILJET;

    public function __construct(){
        $this->provider = ProviderHelper::getProviderByKey(ProviderHelper::MAILJET);
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $list
     * @return string
     */
    protected function getIdFromListResult($list){
        return $list[0]["ID"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $list
     * @return string
     */
    protected function getNameFromListResult($list){
        return $list[0]["Name"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $list
     * @return string
     */
    protected function getTotalSubscriberFromListResult($list){
        return $list[0]["SubscriberCount"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getEmailSubscriberFromSubscribersResult($subscriber){
        return $subscriber["Contact"]["Email"]["Email"];
    }

     /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getLastNameSubscriberFromSubscribersResult($subscriber){
        if(!$this->contactData){
            return null;
        }
        
        $arr = array_values(array_filter($this->contactData, function($ar) {
            return in_array($ar["Name"], 
                apply_filters(DELIPRESS_SLUG . "_last_name_subscriber_import_mailjet", array(
                    "last_name",
                    "lastname"
                ))
            );
        }));

        if(empty($arr)){
            return "";
        }

        return $arr[0]["Value"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return void
     */
    protected function getSubscriberMetaData($subscriber){
        $result = $this->providerApi->getContactMetaData($subscriber["Contact"]["ID"]);

        if(!$result["success"]){
            $this->contactData = null;
        }
        
        $this->contactData = $result["results"][0]["Data"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getFirstNameSubscriberFromSubscribersResult($subscriber){
        if(!$this->contactData){
            return null;
        }
        
        $arr = array_values(array_filter($this->contactData, function($ar) {
            return in_array($ar["Name"], 
                apply_filters(DELIPRESS_SLUG . "_first_name_subscriber_import_mailjet", array(
                    "first_name",
                    "firstname"
                ))
            );
        }));

        if(empty($arr)){
            return "";
        }

        return $arr[0]["Value"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getCreatedAtSubscriberFromSubscribersResult($subscriber){
        return new \DateTime($subscriber["Contact"]["CreatedAt"]);
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getIdSubscriberFromSubscribersResult($subscriber){
        return $subscriber["Contact"]["ID"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getIsUnsubscribeFromSubscriberResult($subscriber){
        return $subscriber["IsUnsubscribed"];
    }

    /**
     * @see AbstractProviderImport
     * 
     * @param array $subscriber
     * @return string
     */
    protected function getStatusSubscribeFromSubscriberResult($subscriber){
        return ($subscriber["IsUnsubscribed"]) ? StatusHelper::UNSUBSCRIBE : StatusHelper::SUBSCRIBE;
    }

}

