<?php

namespace Delipress\WordPress\Services\Provider\Mailjet;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Models\AbstractModel\AbstractProviderWebhook;

use Delipress\WordPress\Models\ListModel;

use Delipress\WordPress\Helpers\ProviderHelper;



/**
 * MailjetWebhook
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class MailjetWebhook extends AbstractProviderWebhook {

    protected $provider = ProviderHelper::MAILJET;


    /**
     * @filter DELIPRESS_SLUG . "_type_webhooks_" . $this->provider
     * @filter DELIPRESS_SLUG . "_webhook_on_list_params_" . $this->provider
     * 
     * @return array
     */
    public function createWebhook(){
                    
        $webhooksResult = $this->providerApi->listWebhook();


        $typeWebhooks = apply_filters(DELIPRESS_SLUG . "_type_webhooks_" . $this->provider, 
            array(
                "unsub",
            )
        );

        $options = array();

        foreach($typeWebhooks as $key => $webhook){
            $params = array(
                "EventType"  => $webhook,
                "url"     => ""
            );

            $params["events"][$webhook] = true;

            switch($webhook){
                case "unsub":
                    $params["url"] = $this->webhookServices->getUrlWebhookUnsubscribe($this->provider);
                    break;
            }

            $params = apply_filters(DELIPRESS_SLUG . "_webhook_on_list_params_" . $this->provider, $params);

            $webhookInWork = null;
            if($webhooksResult["success"] && !empty($webhooksResult["results"])){
                $webhookInWork = array_search($webhook, array_column($webhooksResult["results"], 'EventType'));
            }

            $forceRewriteWebhooks = apply_filters(DELIPRESS_SLUG . "_force_rewrite_webhooks_" . $this->provider, true);

            if($webhookInWork === null ){
                $response = $this->providerApi
                                ->createWebhook($params);
            }
            else if($forceRewriteWebhooks){
                $params["ID"] = $webhooksResult["results"][$webhookInWork]["ID"];
                $response = $this->providerApi
                                 ->updateWebhook($params);
            }

            if($response["success"]){
                $options[$response["results"][0]["ID"]] = array(
                    "type"         => $webhook,
                    "url"          => $params["url"],
                    "APIKeyID"     => $response["results"][0]["APIKeyID"],
                    "provider"     => $this->provider
                ); 
            }
        }

        $this->webhookOptionServices
                ->setOptions($options);

    }

    /**
     * @return void
     */
    public function webhookUnsubscribe(){

        $_POST = json_decode(file_get_contents('php://input'), true);

        if(!isset($_POST["mj_list_id"]) || !isset($_POST["email"])){
            return;
        }

        $list       = $this->listServices->getListByProviderId($this->provider, $_POST["mj_list_id"]);
        $subscriber = $this->subscriberServices->getSubsriberByEmail($_POST["email"]);
        
        
        $this->unsubscribe(
            array(
                "subscriber" => $subscriber,
                "list"       => $list
            )
        );
    }




}

