<?php

namespace Delipress\WordPress\Services\Provider;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\FactoryInterface;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Helpers\ProviderHelper;

use Delipress\WordPress\Services\Provider\Mailjet\MailjetApi;
use Delipress\WordPress\Services\Provider\Mailchimp\MailchimpApi;

use Delipress\WordPress\Services\Provider\Mailjet\MailjetWebhook;
use Delipress\WordPress\Services\Provider\Mailchimp\MailchimpWebhook;

use Delipress\WordPress\Services\Provider\Mailjet\MailjetStatistic;
use Delipress\WordPress\Services\Provider\Mailchimp\MailchimpStatistic;

/**
 * ProviderApiFactory
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class ProviderApiFactory implements FactoryInterface, MediatorServicesInterface{

    /**
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){
        $this->optionServices                  = $services["OptionServices"];
        $this->webhookOptionServices           = $services["WebhookOptionServices"];
        $this->webhookServices                 = $services["WebhookServices"];
        $this->listServices                    = $services["ListServices"];
        $this->createSubscriberServices        = $services["CreateSubscriberServices"];
        $this->subscriberServices              = $services["SubscriberServices"];
        $this->deleteSubscriberServices        = $services["DeleteSubscriberServices"];
        $this->synchronizeListServices         = $services["SynchronizeListServices"];

    }

    /** 
     * @filter DELIPRESS_SLUG . "_get_provider_api_factory"
     * 
     * @param  string $provider
     * @return string
     */
    public function getProviderApi($provider){
        switch($provider){
            case ProviderHelper::MAILJET:
                $api = new MailjetApi();
                break;
            case ProviderHelper::MAILCHIMP:
                $api = new MailchimpApi();
                break;
            default:
                $api = apply_filters(DELIPRESS_SLUG . "_get_provider_api_factory", $provider);
                break;
        }

        if($api instanceOf MediatorServicesInterface){
            $api->setServices(
                array(
                    "OptionServices" => $this->optionServices
                )
            );
        }

        return $api;
    }

    /** 
     * @filter DELIPRESS_SLUG . "_get_provider_webhook_factory"
     * 
     * @param  string $provider
     * @return string
     */
    public function getProviderWebhook($provider){
        switch($provider){
            case ProviderHelper::MAILJET:
                $webhook = new MailjetWebhook();
                break;
            case ProviderHelper::MAILCHIMP:
                $webhook = new MailchimpWebhook();
                break;
            default:
                $webhook = apply_filters(DELIPRESS_SLUG . "_get_provider_webhook_factory", $provider);
                break;
        }

        if($webhook instanceOf MediatorServicesInterface){
            $webhook->setServices(
                array(
                    "OptionServices"             => $this->optionServices,
                    "SynchronizeListServices"    => $this->synchronizeListServices,
                    "WebhookOptionServices"      => $this->webhookOptionServices,
                    "WebhookServices"            => $this->webhookServices,
                    "CreateSubscriberServices"   => $this->createSubscriberServices,
                    "ListServices"               => $this->listServices,
                    "SubscriberServices"         => $this->subscriberServices,
                    "DeleteSubscriberServices"   => $this->deleteSubscriberServices
                )
            );
        }

        return $webhook;
    }

    /**
     *
     * @param string $provider
     * @return AbstractProviderStatistic
     */
    public function getProviderStatistic($provider){
        switch($provider){
            case ProviderHelper::MAILJET:
                $statistic = new MailjetStatistic();
                break;
            case ProviderHelper::MAILCHIMP:
                $statistic = new MailchimpStatistic();
                break;
            default:
                $statistic = apply_filters(DELIPRESS_SLUG . "_get_provider_statistic_factory", $provider);
                break;
        }

        return $statistic;
    }
}


