<?php

namespace Delipress\WordPress\Services\Provider;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\FactoryInterface;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Helpers\ProviderHelper;

use Delipress\WordPress\Services\Provider\Mailjet\MailjetImport;
use Delipress\WordPress\Services\Provider\Mailjet\MailjetExport;
use Delipress\WordPress\Services\Provider\Mailchimp\MailchimpImport;
use Delipress\WordPress\Services\Provider\Mailchimp\MailchimpExport;

use Delipress\WordPress\Async\ImportBackgroundProcess;
use Delipress\WordPress\Async\ExportToProviderBackgroundProcess;
/**
 * ProviderImportExportFactory
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class ProviderImportExportFactory implements FactoryInterface, MediatorServicesInterface{

    /**
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){
        $this->optionServices          = $services["OptionServices"];
        $this->providerServices        = $services["ProviderServices"];
        $this->listServices            = $services["ListServices"];
        $this->synchronizeListServices = $services["SynchronizeListServices"];

        $this->importBackgroundProcess           = new ImportBackgroundProcess($services["ProviderServices"],           $services["OptionServices"]);
        $this->exportToProviderBackgroundProcess = new ExportToProviderBackgroundProcess($services["ProviderServices"], $services["OptionServices"]);

    }


    /** 
     * @filter DELIPRESS_SLUG . "_get_provider_import_factory"
     * 
     * @param  string $provider
     * @return string
     */
    public function getProviderImport($provider){

        switch($provider){
            case ProviderHelper::MAILJET:
                $import = new MailjetImport();
                break;
            case ProviderHelper::MAILCHIMP:
                $import = new MailchimpImport();
                break;
            default:
                $import = apply_filters(DELIPRESS_SLUG . "_get_provider_import_factory", $provider);
                break;
        }

        if($import instanceOf MediatorServicesInterface){
            $import->setServices(
                array(
                    "OptionServices"          => $this->optionServices,
                    "SynchronizeListServices" => $this->synchronizeListServices,
                )
            );
        }
        
        $import->setBackgroundProcess($this->importBackgroundProcess);
        return $import;
    }

    /** 
     * @filter DELIPRESS_SLUG . "_get_provider_export_factory"
     * 
     * @param  string $provider
     * @return string
     */
    public function getProviderExport($provider){
        
        switch($provider){
            case ProviderHelper::MAILJET:
                $export = new MailjetExport();
                break;
            case ProviderHelper::MAILCHIMP:
                $export = new MailchimpExport();
                break;
            default:
                $export = apply_filters(DELIPRESS_SLUG . "_get_provider_export_factory", $provider);
                break;
        }

        if($export instanceOf MediatorServicesInterface){
            $export->setServices(
                array(
                    "OptionServices"          => $this->optionServices,
                    "SynchronizeListServices" => $this->synchronizeListServices,
                )
            );
        }
        
        $export->setBackgroundProcess($this->exportToProviderBackgroundProcess);
        return $export;
    }

}


