<?php

namespace Delipress\WordPress\Services\Provider;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\ServiceInterface;
use DeliSkypress\Models\FactoryInterface;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Helpers\ProviderHelper;
use Delipress\WordPress\Helpers\PageAdminHelper;
use Delipress\WordPress\Helpers\ActionHelper;


/**
 * ProviderServices
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class ProviderServices implements ServiceInterface, MediatorServicesInterface{

    public function __construct(
        FactoryInterface $providerSettingsFactory, 
        FactoryInterface $providerApiFactory, 
        FactoryInterface $providerImportExportFactory
    ){
        $this->providerSettingsFactory         = $providerSettingsFactory;
        $this->providerApiFactory              = $providerApiFactory;
        $this->providerImportExportFactory     = $providerImportExportFactory;
    }

    /**
     * @see MediatorServicesInterface
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){
        if(!array_key_exists("OptionServices", $services)){
            throw new Exception("Miss OptionServices");
        }

        $this->optionServices = $services["OptionServices"];

        if($this->providerApiFactory instanceOf MediatorServicesInterface){
            $this->providerApiFactory->setServices($services); 
        }

        if($this->providerSettingsFactory instanceOf MediatorServicesInterface){
            $this->providerSettingsFactory->setServices($services); 
        }

        if($this->providerImportExportFactory instanceOf MediatorServicesInterface){
            $this->providerImportExportFactory->setServices($services); 
        }

    }

    /**
     * @return string
     */
    public function getUrlFormAdminPost(){
        
        $provider = ProviderHelper::getProviderFromUrl();

        return add_query_arg(
            array(
                'action'   => ActionHelper::SETTINGS_PROVIDER,
                'provider' => $provider["key"]
            ), 
            admin_url( 'options.php' )
        );
    }

    /**
     * 
     * @param string $provider
     * @return string
     */
    public function getUrlDisconnectProvider($provider){
        return wp_nonce_url( 
            add_query_arg(
                array(
                    "action"   => ActionHelper::DISCONNECT_PROVIDER,
                    "provider" => $provider
                ),
                admin_url("admin-post.php")
            ),
            ActionHelper::DISCONNECT_PROVIDER
        );
    }

    /**
     * 
     * @param string $provider
     * @param array $options
     * @return Object
     */
    public function prepareProvidersSettings($provider, $options){
        return $this->getProviderSettings($provider)->prepareProvidersSettings($options);

    }

    /**
     * 
     * @param string $provider
     * @return Object
     */
    public function getProviderSettings($provider){

        $providerSettings = $this->providerSettingsFactory
                                 ->getProviderSettings($provider);

        $providerSettings->setApi(
            $this->getProviderApi($provider)
        );
        
        switch($provider){
            case ProviderHelper::MAILJET:
                $providerSettings->setProviderWebhook(
                    $this->getProviderWebhook($provider)
                );
            break;
        }

        return $providerSettings;
    }

    /**
     * 
     * @param string $provider
     * @return Object
     */
    public function getProviderImport($provider){
        $providerImport = $this->providerImportExportFactory
                               ->getProviderImport($provider);

        $providerImport->setProviderWebhook(
            $this->getProviderWebhook($provider)
        );
        
        return $providerImport->setApi(
                        $this->getProviderApi($provider)
                    );

    }

    /**
     * 
     * @param string $provider
     * @return Object
     */
    public function getProviderExport($provider){
        $providerImport = $this->providerImportExportFactory
                               ->getProviderExport($provider);

        return $providerImport->setApi(
                        $this->getProviderApi($provider)
                    );

    }
   
    /**
     * 
     * @param string $provider
     * @return Object
     */
    public function getProviderWebhook($provider){
        $providerWebhook = $this->providerApiFactory
                               ->getProviderWebhook($provider);

        return $providerWebhook->setApi(
                        $this->getProviderApi($provider)
                    );

    }

    /**
     * 
     * @param string $provider
     * @return Object
     */
    public function getProviderApi($provider){
        return $this->providerApiFactory
                    ->getProviderApi($provider);
    }

    /**
     * 
     * @param string $provider
     * @return Object
     */
    public function getProviderStatistic($provider){
        $providerStatistic = $this->providerApiFactory
                                 ->getProviderStatistic($provider);

        return $providerStatistic->setApi(
                        $this->getProviderApi($provider)
                    );
    }
}


