<?php

namespace Delipress\WordPress\Services\Subscriber;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\ServiceInterface;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Helpers\PostTypeHelper;
use Delipress\WordPress\Helpers\TaxonomyHelper;
use Delipress\WordPress\Helpers\ProviderHelper;
use Delipress\WordPress\Helpers\SourceSubscriberHelper;
use Delipress\WordPress\Helpers\ActionHelper;
use Delipress\WordPress\Helpers\DataEncoder;

use Delipress\WordPress\Models\SubscriberModel;
use Delipress\WordPress\Models\ListModel;

/**
 * ConfirmSubscribeServices
 *
 * @author DeliPress
 * @version 1.0.0
 * @since 1.0.0
 */
class ConfirmSubscribeServices implements ServiceInterface, MediatorServicesInterface{

    /**
     * @see MediatorServicesInterface
     *
     * @param array $services
     * @return void
     */
    public function setServices($services){

        $this->optionServices                   = $services["OptionServices"];
        $this->providerServices                 = $services["ProviderServices"];
        $this->emailHtmlServices                = $services["EmailHtmlServices"];
        $this->subscriberTableServices          = $services["SubscriberTableServices"];
        $this->listSubscriberTableServices      = $services["ListSubscriberTableServices"];
        $this->synchronizeSubscriberServices    = $services["SynchronizeSubscriberServices"];

    }

    /**
     * @return string
     */
    public function getConfirmSubscribeUrl($subscriberId, $email){
        return wp_nonce_url(
            add_query_arg(
                array(
                    "data"   => DataEncoder::encodeData(
                        array(
                            "subscriber_id"    => $subscriberId,
                            "subscriber_email" => $email
                        )
                    ),
                    "action" => ActionHelper::CONFIRM_SUBSCRIBE
                ),
                home_url()
            ),
            ActionHelper::CONFIRM_SUBSCRIBE
        );
    }


    /**
     * Send confirm subscribe
     *
     * @param string $email
     * @return array
     */
    public function sendConfirmSubscribe($subscriberId, $email){

        $provider    = $this->optionServices->getProvider();
        $providerApi = $this->providerServices->getProviderApi($provider["key"]);

        ob_start();
        include_once DELIPRESS_PLUGIN_DIR_EMAILS . "/confirm_subscribe.php";
        $html = ob_get_contents();
        ob_end_clean();

        $html = $this->emailHtmlServices->prepareEmailHtml($html);
        $html = str_replace("[delipress_request_confirm_subscribe]", $this->getConfirmSubscribeUrl($subscriberId, $email), $html);

        $response = $providerApi->sendEmail(
            array(
                "subject" => __("Just one more step to subscribe!", "delipress"),
                "html"    => $html,
                "emails" => array(
                    $email
                )
            )
        );

        return $response;

    }

    /**
     * @action DELIPRESS_SLUG . "_confirm_subscriber"
     *
     * @param SubscriberModel $subscriber
     * @return void
     */
    public function confirmSubscriber(SubscriberModel $subscriber){

        do_action(DELIPRESS_SLUG . "_confirm_subscriber", $subscriber);

        $this->subscriberTableServices->update(
            array(
                "is_confirmed" => 1
            ),
            array(
                "id" => $subscriber->getId()
            )
        );

        $listsToSynchronize = $this->listSubscriberTableServices->getListSubscribers(
            array(
                "selects" => array(
                    "term_taxonomy_id"
                ),
                "query" => array(
                    array(
                        "field" => "subscriber_id",
                        "operator" => "=",
                        "value" => $subscriber->getId(),
                        "type" => "int"
                    )
                )
            )
        );

        foreach($listsToSynchronize as $key => $value){
            $list = new ListModel();
            $list->setListByTermId($value->term_taxonomy_id);

            $this->synchronizeSubscriberServices->subscriberSynchronizeOnList($list, $subscriber->getId(), $subscriber->getEmail());
        }

        $this->listSubscriberTableServices->update(
            array(
                "status" => "subscribe"
            ),
            array(
                "subscriber_id" => $subscriber->getId()
            )
        );



    }

}
