<?php

namespace Delipress\WordPress\Services\Subscriber;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\ServiceInterface;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Helpers\TaxonomyHelper;
use Delipress\WordPress\Helpers\PostTypeHelper;
use Delipress\WordPress\Helpers\AdminNoticesHelper;
use Delipress\WordPress\Helpers\CodeErrorHelper;

use Delipress\WordPress\Models\ListModel;
use Delipress\WordPress\Models\SubscriberModel;

use Delipress\WordPress\Traits\PrepareParams;
use Delipress\WordPress\Traits\Listing\ListTrait;
use Delipress\WordPress\Traits\Subscriber\SubscriberTrait;

use Delipress\WordPress\Services\Table\TableServices;


/**
 * DeleteSubscriberServices
 *
 * @author DeliPress
 * @version 1.0.0
 * @since 1.0.0
 */
class DeleteSubscriberServices implements ServiceInterface, MediatorServicesInterface{

    use ListTrait;
    use SubscriberTrait;
    use PrepareParams;

    protected $missingParameters = array();

    /**
     * @see MediatorServicesInterface
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){
        if(!array_key_exists("OptionServices", $services)){
            throw new Exception("Miss OptionServices");
        }
        if(!array_key_exists("ProviderServices", $services)){
            throw new Exception("Miss ProviderServices");
        }

        $this->optionServices   = $services["OptionServices"];
        $this->providerServices = $services["ProviderServices"];

    }


    /**
     * 
     * @param ListModel $list
     * @param SubscriberModel $subscriber
     * @return array
     */
    protected function deleteOneSubscriberOnList(ListModel $list, SubscriberModel $subscriber){

        
        $provider = $this->optionServices->getProvider();
        $response = array(
            "success" => true
        );

        if(
            array_key_exists("is_connect", $provider) &&
            $provider["is_connect"]
        ){
            $listConnectId = $list->getProviderId();

            $response = $this->providerServices
                             ->getProviderApi($provider["key"])
                             ->deleteSubscriberOnList($listConnectId,
                                array(
                                    "email"  => $subscriber->getEmail(),
                                    "id"     => $subscriber->getProviderIdByListId($list->getId())
                                )    
                            );

            if(!$response["success"]){
                $response = array(
                    "success" => false
                );
            }
            
        }
        
        $this->deleteListSubscriber($list, $subscriber);
        
        return $response;
    }

    /**
     *
     * @param ListModel $list
     * @param SubscriberModel $subscriber
     * @return void
     */
    public function unsubscribeListSusbcriber(ListModel $list, SubscriberModel $subscriber){
        TableServices::getTable("ListSubscriberTableServices")->update(
            array(
                "status" => "unsubscribe"
            ),
            array(
                "term_taxonomy_id" => $list->getId(),
                "subscriber_id"    => $subscriber->getId()
            )
        );
    }   

    /**
     *
     * @param SubscriberModel $subscriber
     * @param ListModel $list
     * @return void
     */
    public function deleteListSubscriber(ListModel $list, SubscriberModel $subscriber){
        TableServices::getTable("ListSubscriberTableServices")->deleteListSubscriber($subscriber->getId(), $list->getId());
    }

    /**
     * @action DELIPRESS_SLUG . "_before_delete_subscriber_from_list"
     * @action DELIPRESS_SLUG . "_after_delete_subscriber_from_list"
     * 
     * @return void
     */
    public function deleteSubscriberFromList(){
        $this->fieldsGets = array(
            "list_id"       => "checkListExist",
            "subscriber_id" => "checkSubscriberExist"
        );

        $this->fieldsRequired = array(
            "list_id",
            "subscriber_id"
        );

        $params = $this->getGetParams("fields");

        do_action(DELIPRESS_SLUG . "_before_delete_subscriber_from_list", $params);

        if(!empty($this->missingParameters)){
            AdminNoticesHelper::registerError(
                CodeErrorHelper::ADMIN_NOTICE,
                CodeErrorHelper::getMessage(CodeErrorHelper::TRY_CHEAT)
            );
        }

        $response = $this->deleteOneSubscriberOnList($params["list_id"], $params["subscriber_id"]);
        
        if($response["success"] ) {
            AdminNoticesHelper::registerSuccess(
                CodeErrorHelper::ADMIN_NOTICE,
                CodeErrorHelper::getMessage(CodeErrorHelper::DELETE_SYNCHRONIZE_SUBSCRIBER_ON_LIST_SUCCESS)
            );
        }
        else{
            AdminNoticesHelper::registerError(
                CodeErrorHelper::ADMIN_NOTICE,
                CodeErrorHelper::getMessage(CodeErrorHelper::ADMIN_NOTICE_ERROR_DEFAULT)
            );
        }

        $result = array(
            "success" => true,
            "results" => array(
                "list"       => $params["list_id"],
                "subscriber" => $params["subscriber_id"],
                "synchronize" => $response
                
            )   
        );

        do_action(DELIPRESS_SLUG . "_after_delete_subscriber_from_list", $result);

        return $result;

    }

    /**
     * 
     * @param ListModel $list
     * @param SubscriberModel $subscriber
     * @return array
     */
    public function deleteSubscriberOnList(ListModel $list, SubscriberModel $subscriber){

        return $this->deleteOneSubscriberOnList($list, $subscriber);
    }

    /**
     * 
     * @return void
     */
    public function deleteSubscribersFromList(){
        $this->fieldsPosts = array(
            "list_id"       => "checkListExist",
            "subscribers"   => "checkSubscribersExist"
        );

        $this->fieldsRequired = array(
            "list_id",
            "subscribers"
        );

        $params = $this->getPostParams("fields");

        do_action(DELIPRESS_SLUG . "_before_delete_subscribers_from_list", $params);

        if(!empty($this->missingParameters)){
            AdminNoticesHelper::registerError(
                CodeErrorHelper::ADMIN_NOTICE,
                CodeErrorHelper::getMessage(CodeErrorHelper::TRY_CHEAT)
            );
        }


        foreach($params["subscribers"] as $key => $subscriber){
            $response = $this->deleteOneSubscriberOnList($params["list_id"], $subscriber);
        }
        
        if($response["success"] ) {
            AdminNoticesHelper::registerSuccess(
                CodeErrorHelper::ADMIN_NOTICE,
                CodeErrorHelper::getMessage(CodeErrorHelper::DELETE_SYNCHRONIZE_SUBSCRIBER_ON_LIST_SUCCESS)
            );
        }
        else{
            AdminNoticesHelper::registerError(
                CodeErrorHelper::ADMIN_NOTICE,
                CodeErrorHelper::getMessage(CodeErrorHelper::ADMIN_NOTICE_ERROR_DEFAULT)
            );
        }

        $result = array(
            "success" => true,
            "results" => array(
                "list"        => $params["list_id"],
                "subscribers" => $params["subscribers"],
                "synchronize" => $response
                
            )   
        );

        do_action(DELIPRESS_SLUG . "_after_delete_subscribers_from_list", $result);

        return $result;
    }
}









