<?php

namespace Delipress\WordPress\Services\Subscriber;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\ServiceInterface;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Helpers\PostTypeHelper;
use Delipress\WordPress\Helpers\PageAdminHelper;
use Delipress\WordPress\Helpers\ActionHelper;

use Delipress\WordPress\Models\SubscriberModel;

use Delipress\WordPress\Services\Table\TableServices;

/**
 * SubscriberServices
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class SubscriberServices implements ServiceInterface, MediatorServicesInterface{

    /**
     * @see MediatorServicesInterface
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){

        $this->providerServices     = $services["ProviderServices"];
        $this->emailHtmlServices    = $services["EmailHtmlServices"];

    }

     /**
     *
     * @param string $email
     * @return null|SubscriberModel
     */
    public function getSubsriberByEmail($email){

        $table = TableServices::getTable("SubscriberTableServices");

        $subscriber = $table->getSubscriber(
            array(
                "query" => array(
                    array(
                        "operator" => "=",
                        "field"    => "email",
                        "value"    => $email
                    )
                )
            )
        );

        if(empty($subscriber)){
            return null;
        }

        $subscriberModel = new SubscriberModel();
        $subscriberModel->setSubscriber($subscriber);

        return $subscriberModel;
    }

    /**
     * 
     * @param int $listId
     * @return string
     */
    public function getPageSubscribersUrl($listId){

        return add_query_arg(
            array(
                "page"    => PageAdminHelper::getPageNameByConst(PageAdminHelper::PAGE_LISTS),
                "action"  => "subscribers",
                "list_id" => $listId
            ),
            admin_url("admin.php")
        );

    }

    /**
     * 
     * @param int $listId
     * @return string
     */
    public function getCreateUrl($listId, $subscriberId = null){

        return add_query_arg(
            array(
                "page"          => PageAdminHelper::getPageNameByConst(PageAdminHelper::PAGE_LISTS),
                "action"        => "subscribers-create",
                "list_id"       => $listId,
                "subscriber_id" => $subscriberId
            ),
            admin_url("admin.php")
        );

    }

    /**
     * 
     * @param int $listId
     * @return string
     */
    public function getPageSubscribersImport($listId = null, $step = 1){

        return add_query_arg(
            array(
                "page"          => PageAdminHelper::getPageNameByConst(PageAdminHelper::PAGE_LISTS),
                "action"        => "subscribers-import",
                "list_id"       => $listId,
                "step"          => $step
            ),
            admin_url("admin.php")
        );

    }


    /**
     * 
     * @param int $subscriberId
     * @param int $listId
     * @return string
     */
    public function getDeleteSubscriberFromList($subscriberId, $listId){
        return wp_nonce_url(
            admin_url( 
                sprintf(
                    'admin-post.php?action=%s&subscriber_id=%s&list_id=%s',
                    ActionHelper::DELETE_SUBSCRIBER_LIST,
                    $subscriberId, 
                    $listId
                )
            ),
            ActionHelper::DELETE_SUBSCRIBER_LIST
        );
    }
        

    /**
     * 
     * @param int $listId
     * @return string
     */
    public function getDeleteSubscribersFromList($listId){
        return wp_nonce_url( 
            add_query_arg(
                array(
                    "action"  => ActionHelper::DELETE_SUBSCRIBERS_LIST,
                    "list_id" => $listId
                ),
                admin_url("admin-post.php")
            ),
            ActionHelper::DELETE_SUBSCRIBERS_LIST
        );
    }
        



}









