<?php

namespace Delipress\WordPress\Services\Subscriber;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use DeliSkypress\Models\ServiceInterface;
use DeliSkypress\Models\MediatorServicesInterface;

use Delipress\WordPress\Helpers\ProviderHelper;

use Delipress\WordPress\Models\SubscriberModel;
use Delipress\WordPress\Models\ListModel;


/**
 * SynchronizeSubscriberServices
 *
 * @author DeliPress
 * @version 1.0.0
 * @since 1.0.0
 */
class SynchronizeSubscriberServices implements ServiceInterface, MediatorServicesInterface {


    /**
     * @see MediatorServicesInterface
     * 
     * @param array $services
     * @return void
     */
    public function setServices($services){

        $this->optionServices              = $services["OptionServices"];
        $this->providerServices            = $services["ProviderServices"];
        $this->listSubscriberTableServices = $services["ListSubscriberTableServices"];
        $this->subscriberTableServices     = $services["SubscriberTableServices"];

    }

    /**
     * 
     * @param ListModel $list
     * @param int $subscriberId
     * @param string $email
     * @param array $params
     * @return void
     */
    public function subscriberSynchronizeOnList(ListModel $list, $subscriberId, $email, $params = array()){

        $params["safeError"] = (isset($params["safeError"])) ? $params["safeError"] : false;
        $provider            = $this->optionServices->getProvider();
        $providerMD5         = $this->optionServices->getMd5Provider();

        $response = array(
            "success" => true
        );
        
        if(
            array_key_exists("is_connect", $provider) &&
            $provider["is_connect"] &&
            $list->isSynchronizeWithProvider($provider["key"], $providerMD5)
        ){
            $response = $this->synchronizeSubscriberOnList(
                $list->getProviderId(),
                array_merge(
                    $params,
                    array(
                        "email"       => $email
                    )
                ),
                $params["safeError"]
            );
            
            if($response["success"]){
                $providerSubscriberId = "";
                switch($provider["key"]){
                    case ProviderHelper::MAILCHIMP:
                        $providerSubscriberId = $response["results"]["id"];
                        break;
                    case ProviderHelper::MAILJET:
                        $providerSubscriberId = $response["results"][0]["ContactID"];
                        break;
                    default:
                        $providerSubscriberId = apply_filters(DELIPRESS_SLUG . "_subscriber_synchronize_on_list_" . $provider["key"], $response);
                        break;
                }
                
                $this->subscriberTableServices->update(
                    array(
                        "provider_id"    => $providerSubscriberId,
                    ),
                    array(
                        "id" => $subscriberId
                    )
                );

                $this->listSubscriberTableServices->update(
                    array(
                        "is_synchronize" => 1,
                        "provider_id"    => $providerSubscriberId,
                        "provider"       => $provider["key"]
                    ),
                    array(
                        "subscriber_id" => $subscriberId
                    )
                );

                $response["results"]["provider_id"] = $providerSubscriberId;
                $response["results"]["synchronize"] = 1;
            }
            else{
                if(!$params["safeError"]){
                    $this->listSubscriberTableServices->deleteListSubscriber($subscriberId, $list->getId());
                }
            }

        }

        return $response;
    }

    /**
     * 
     * @param ListModel $list
     * @param int $subscriberId
     * @param string $email
     * @param array $params
     * @return void
     */
    public function editSubscriberSynchronizeOnList(ListModel $list, SubscriberModel $subscriber, $params){

        $params["safeError"] = (isset($params["safeError"])) ? $params["safeError"] : false;
        $provider            = $this->optionServices->getProvider();
        $providerMD5         = $this->optionServices->getMd5Provider();

        $response = array(
            "success" => true
        );
        
        if(
            array_key_exists("is_connect", $provider) &&
            $provider["is_connect"] &&
            $list->isSynchronizeWithProvider($provider["key"], $providerMD5)
        ){
            $response = $this->editSynchronizeSubscriberOnList(
                $list->getProviderId(),
                $subscriber->getProviderId(),
                $params,
                $params["safeError"]
            );

            if($response["success"]){
                $providerSubscriberId = "";
                switch($provider["key"]){
                    case ProviderHelper::MAILCHIMP:
                        $providerSubscriberId = $response["results"]["id"];
                        break;
                }
                
                if(!empty($providerSubscriberId)){
                    $this->subscriberTableServices->update(
                        array(
                            "provider_id"    => $providerSubscriberId,
                        ),
                        array(
                            "id" => $subscriber->getId()
                        )
                    );
                }
            }
            
        }

        return $response;
    }

    /**
     * @action DELIPRESS_SLUG . "_before_synchronize_subscriber_on_list"
     * @action DELIPRESS_SLUG . "_after_synchronize_subscriber_on_list"
     * 
     * @param int $listId
     * @param array $params
     * @param bool $safeError
     * @return array
     */
    public function synchronizeSubscriberOnList($listId, $params, $safeError = false){

        $provider        = $this->optionServices->getProvider();

        do_action(DELIPRESS_SLUG . "_before_synchronize_subscriber_on_list", $listId, $params, $provider);

        $response = $this->providerServices
                         ->getProviderApi($provider["key"])
                         ->setSafeError($safeError)
                         ->createSubscriberOnList($listId, $params);


        do_action(DELIPRESS_SLUG . "_after_synchronize_subscriber_on_list", $response);

        return $response;
    }

    /**
     * @action DELIPRESS_SLUG . "_before_edit_synchronize_subscriber_on_list"
     * @action DELIPRESS_SLUG . "_after_edit_synchronize_subscriber_on_list"
     * 
     * @param int $listId
     * @param int $subscriberId
     * @param array $params
     * @param bool $safeError
     * @return array
     */
    public function editSynchronizeSubscriberOnList($listId, $subscriberId, $params, $safeError = false){
        $provider        = $this->optionServices->getProvider();
        
        do_action(DELIPRESS_SLUG . "_before_edit_synchronize_subscriber_on_list", $listId, $subscriberId, $params, $provider);

        $response = $this->providerServices
                         ->getProviderApi($provider["key"])
                         ->setSafeError($safeError)
                         ->editSubscriberOnList($listId, $subscriberId, $params);


        do_action(DELIPRESS_SLUG . "_after_edit_synchronize_subscriber_on_list", $response);

        return $response;
    }
    
}









