<?php

namespace Delipress\WordPress\Strategy;

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Services\Table\TableServices;

use Delipress\WordPress\Helpers\ProviderHelper;

/**
 * AbstractImportSubscriber
 *
 * @author Delipress
 * @version 1.0.0
 * @since 1.0.0
 */
class AbstractImportSubscriber  {

    protected $range = 100;

    /**
     * 
     * @param array $file
     * @return AbstractImportSubscriber
     */
    public function setFile($file){
        $this->file = $file;
        return $this;
    }

    /**
     * 
     * @param string $provider
     * @return AbstractImportSubscriber
     */
    public function setProvider($provider){
        $this->provider = $provider;
        return $this;
    }

    /**
     * 
     * @param array $data
     * @return AbstractImportSubscriber
     */
    public function setData($data){
        $this->data = $data;
        return $this;
    }

    /**
     * @return array
     */
    public function getData(){
        return $this->data;
    }
    
    /** 
     * @return int
     */
    public function getRange(){
        return apply_filters(DELIPRESS_SLUG  . "_abstract_import_subscriber_range", $this->range);
    }

    /**
     *
     * @param Object $backgroundProcess
     * @return AbstractImportSubscriber
     */
    public function setBackgroundProcess($backgroundProcess){
        $this->backgroundProcess = $backgroundProcess;
        return $this;
    }

    /**
     * @return Object
     */
    public function getBackgroundProcess(){
        return $this->backgroundProcess;
    }

    /**
     * @return void
     */
    public function execute(){

        $data = $this->getData();
        
        if(empty($data) || !isset($data["create_import"]) ){
            return;
        }

        $metaTable = TableServices::getTable("MetaTableServices");

        foreach($data["create_import"] as $key => $value){
            if(!empty($value)){
                $result = $metaTable->getMetaByName($value);

                if(!$result){
                    $metaId = $metaTable->insertMeta(array(
                        "name" => $value
                    ));
                }
                else{
                    $metaId = (int) $result["id"];
                }

                $data["meta_import"][$key] = $metaId;
            }
        }
        
        $this->setData($data);

    }

    /**
     * @param array $params
     * 
     * @return void
     */
    public function pushBackgroundProcess($params){
        $range                   = $this->getRange();
        $countCall               = ceil($params["total_subscribers"] /  $range);

        for ($i=1; $i <= $countCall; $i++) {
            $arr = array(
                "page"              => $i,
                "provider"          => $this->provider,
                "limit"             => $range,
                "total_call"        => $countCall,
                "file"              => $this->file,
                "total_subscribers" => $params["total_subscribers"],
            );

            $arr = array_merge($arr, $params, $this->getData());

            $this->getBackgroundProcess()->push_to_queue($arr);
        }

        
        $this->getBackgroundProcess()->save()->dispatch();

    }

}

