<?php

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Helpers\TaxonomyHelper;
use Delipress\WordPress\Helpers\PrepareModelHelper;
use Delipress\WordPress\Helpers\ErrorFieldsNoticesHelper;
use Delipress\WordPress\Helpers\AdminFormValues;
use Delipress\WordPress\Helpers\CodeErrorHelper;
use Delipress\WordPress\Helpers\ColorHelper;

$list   = PrepareModelHelper::getListFromUrl();
$idList = $list->getId();
$colors = ColorHelper::getColors();
?>

<h1>
    <?php echo esc_html__(get_admin_page_title(), "delipress"); ?>
    <small>
        <?php if(empty($idList)): ?>
            <?php esc_html_e("Add new list","delipress"); ?>
        <?php else: ?>
            <?php esc_html_e("Edit list","delipress"); ?>
        <?php endif; ?>
    </small>
</h1>

<div class="delipress__settings">
    <?php if($list->getId()): ?>
        <input type="hidden" name="list_id" value="<?php echo $list->getId(); ?>" />
    <?php endif; ?>
    <div class="delipress__settings__item delipress__flex">
        <div class="delipress__settings__item__label delipress__f2">
            <label for="<?php echo TaxonomyHelper::LIST_NAME; ?>"><?php esc_html_e('Name your list', 'delipress'); ?></label>
        </div>
        <div class="delipress__settings__item__field delipress__f4">
            <input
                id="<?php echo TaxonomyHelper::LIST_NAME; ?>"
                name="<?php echo TaxonomyHelper::LIST_NAME; ?>"
                type="text"
                class="delipress__input <?php if(ErrorFieldsNoticesHelper::hasError(TaxonomyHelper::LIST_NAME) ): ?> delipress__input--error<?php endif; ?>"
                value="<?php echo esc_attr(AdminFormValues::displayOldValues(TaxonomyHelper::LIST_NAME, $list->getName()) ); ?>"
                placeholder="" />
        </div>
        <div class="delipress__settings__item__help delipress__f5">
            <span class="delipress__mandatory"><?php esc_html_e("Required", "delipress"); ?></span>
            <?php ErrorFieldsNoticesHelper::displayError(TaxonomyHelper::LIST_NAME) ?>
        </div>
    </div>
    <div class="delipress__settings__item delipress__flex">
        <div class="delipress__settings__item__label delipress__f2">
            <label for="color"><?php esc_html_e('Give it a color (optional)', 'delipress'); ?></label>
        </div>
        <div class="delipress__settings__item__field delipress__f4">
            <div class="delipress__simplepicker js-delipress-simplepicker" style="background: <?php $current_color = esc_attr($list->getColor()); echo $current_color; ?>">
                <div class="delipress__simplepicker__icon">
                    <span class="dashicons dashicons-admin-customizer"></span>
                </div>
                <input
                    type="hidden"
                    name="<?php echo TaxonomyHelper::META_LIST_COLOR ?>"
                    class="delipress__simplepicker__input"
                    value="<?php echo $current_color; ?>"
                />
                <ul class="delipress__simplepicker__list">
                    <?php foreach($colors as $color): ?>
                    <li style="background-color:<?php echo $color; ?>"></li>
                    <?php endforeach; ?>
                    <?php do_action(DELIPRESS_SLUG . "_lists_color_create"); ?>
                </ul>
            </div>
        </div>
        <div class="delipress__settings__item__help delipress__f5">
        </div>
    </div>

    <?php if(empty($idList)): ?>
        <button type="submit" class="delipress__button delipress__button--save"><?php esc_html_e('Create list', 'delipress'); ?></button>
    <?php else: ?>
        <button type="submit" class="delipress__button delipress__button--save"><?php esc_html_e('Edit list', 'delipress'); ?></button>
    <?php endif; ?>

</div> <!-- delipress__settings -->

<?php if($idList): ?>
<h2>
    <?php echo esc_html__('Manually sync', "delipress"); ?>
</h2>

<div class="delipress__settings">
    <p><?php esc_html_e(sprintf("In some rare cases you might need to manually resync DeliPress to %s or %s to DeliPress.", ucfirst($provider["key"]), ucfirst($provider["key"]) ), "delipress"); ?></p>
    <a href="<?php echo $this->listServices->executeSynchronizeListSubscriberExport($list); ?>" class="delipress__button delipress__button--soft">
        <span class="dashicons dashicons-arrow-up-alt"></span>
        <?php esc_html_e(sprintf("Synchronize DeliPress to %s", ucfirst($provider["key"]) ), "delipress"); ?>
    </a>
    <span>&nbsp;&nbsp;<?php _e('or', 'delipress') ?>&nbsp;&nbsp;</span>
    <a href="<?php echo $this->listServices->executeSynchronizeListSubscriberImport($list); ?>" class="delipress__button delipress__button--soft">
        <span class="dashicons dashicons-arrow-down-alt"></span>
        <?php esc_html_e(sprintf("Synchronize %s to DeliPress", ucfirst($provider["key"]) ), "delipress"); ?>
    </a>
</div>
<?php endif; ?>
