<?php

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Models\ListModel;
use Delipress\WordPress\Models\OptinModel;
use Delipress\WordPress\Helpers\TaxonomyHelper;
use Delipress\WordPress\Helpers\MarkupIncentiveHelper;

$provider    = $this->optionServices->getProvider();
$providerMD5 = $this->optionServices->getMd5Provider();

$pagedType  = "active";
$paged      = (isset($_GET["paged-" . $pagedType])) ?
                (int) $_GET["paged-" . $pagedType] :
                (
                    (isset($_GET["paged"])) ?  (int) $_GET["paged"] : 1
                );
$numberPerPage  = apply_filters(DELIPRESS_SLUG . "_lists_per_page", 10);

$countTotal     = $this->listServices->getCountListsOnlySynchronizeWithProvider($provider["key"], $providerMD5);
$listValid      = $this->listServices->getListsOnlySynchronizeWithProvider($provider["key"], $providerMD5,
    array(
        "offset" => ($paged * $numberPerPage) - $numberPerPage,
        "number"  => $numberPerPage
    )
);

$licenseStatusValid  = $this->optionServices->isValidLicense();

$listInvalid = $this->listServices->getLists(
     array(
        "meta_query"  => array(
            array(
                'relation' => 'OR',
                array(
                    'key'     => TaxonomyHelper::META_LIST_ID_PROVIDER,
                    'value'   => $provider["key"],
                    'compare' => "NOT LIKE",
                ),
                array(
                    'key'     => TaxonomyHelper::META_LIST_API_KEY_MD5,
                    'compare' => '!=',
                    'value'   => $providerMD5
                ),
                array(
                    'key'     => TaxonomyHelper::META_LIST_API_KEY_MD5,
                    'compare' => 'NOT EXISTS'
                )
            )
        )
    )
);


?>
<?php include_once(DELIPRESS_PLUGIN_DIR_TEMPLATES_ADMIN . "/header_no_forms.php"); ?>

<h1><?php echo esc_html__(get_admin_page_title(), "delipress"); ?> <small><?php esc_html_e("All items","delipress"); ?></small></h1>

<p class="delipress__intro"><?php _e("Manage your lists and subscribers","delipress"); ?></p>

<section class="delipress__section">
    <div class="delipress__list">
        <form action="<?php echo $this->listServices->getDeleteListsUrl(); ?>" method="post" id="form_footer">
            <ul class="delipress__list__content">
                <?php if(!empty($listValid)): ?>
                    <?php foreach($listValid as $key => $list):
                        $isConnector = $list->isConnector();
                        $syncInWork  = $list->synchronizeInWork();
                        $classLi     = ($syncInWork) ?  "delipress__list__item--syncing " : "";
                        $classLi     .= ($isConnector) ? "delipress__list__item--connector" : "";
                    ?>
                        <li class="delipress__list__item delipress__flex delipress__flex--center <?php echo $classLi; ?>">
                            <?php if($syncInWork): ?>
                                <div class="delipress__list__item__progress">
                                    <span><?php _e('This list is currently being synchronized in the background. You can reload the page to check the progress', 'delipress') ?></span>
                                </div>
                            <?php endif; ?>

                            <div class="delipress__list__item__col-box">
                                <?php if(!$isConnector): ?>
                                    <input type="checkbox" id="<?php echo $list->getId(); ?>" class="delipress__checkbox__input" name="lists[]" value="<?php echo $list->getId(); ?>" />
                                    <label for="<?php echo $list->getId(); ?>" class="delipress__checkbox"></label>
                                <?php else: ?>
                                    <span class="dashicons dashicons-wordpress" title="<?php _e('This list is synced with your WordPress users', 'delipress'); ?>"></span>
                                <?php endif; ?>
                            </div>
                            <div class="delipress__f3">
                                <a href="<?php echo $this->subscriberServices->getPageSubscribersUrl($list->getId()); ?>" class="delipress__list__item__title">
                                    <?php echo esc_html($list->getName()); ?>
                                </a>
                            </div>
                            <div class="delipress__f3">
                                <?php if($syncInWork): ?>
                                    <span class="dashicons dashicons-update dashicons--roll"></span>
                                <?php endif; ?>

                                <span class="delipress__list__item__num">
                                    <?php
                                        $total = $list->countSubscribers();
                                        echo $total;
                                    ?>
                                </span>
                                <?php
                                    echo esc_html(
                                            _n(
                                            "subscriber",
                                            "subscribers",
                                            ((int) $total === 0) ? 1 : $total,
                                            "delipress"
                                        )
                                    );

                                ?>

                            </div>
                            <div class="delipress__f3">
                                <span class="delipress__list__item__num">
                                    <?php
                                        $optins = $list->getOptins();
                                        $totalOptin = 0;
                                        if($optins){
                                            $totalOptin = count($optins);
                                        }

                                        echo $totalOptin;
                                    ?>
                                </span>
                                <?php
                                    echo esc_html(
                                            _n(
                                            "Opt-In linked",
                                            "Opt-Ins linked",
                                            ((int) $totalOptin === 0) ? 1 : $totalOptin,
                                            "delipress"
                                        )
                                    );

                                ?>
                            </div>
                            <div class="delipress__f1">
                                <?php esc_html_e('Color', 'delipress'); ?> <div class="delipress__list__item__color" style="background-color: <?php echo esc_attr($list->getColor() ); ?>"></div>
                            </div>
                            <div class="delipress__list__item__col-actions delipress__f5">
                                <a href="<?php echo $this->subscriberServices->getPageSubscribersUrl($list->getId()); ?>" class="delipress__button delipress__button--soft"><?php esc_html_e('Subscribers', 'delipress'); ?></a>
                                <a href="<?php echo $this->listServices->getEditUrl($list->getId()); ?>" class="delipress__button delipress__button--soft"><?php esc_html_e('Settings', 'delipress'); ?></a>
                                <nav class="delipress__more">
                                    <a href="" class="delipress__button delipress__button--soft">
                                        <span class="dashicons dashicons-arrow-down-alt2"></span>
                                    </a>
                                    <ul class="delipress__more__sub">
                                        <li>
                                            <a href="<?php echo $this->subscriberServices->getCreateUrl($list->getId()); ?>">
                                                <?php _e("Add a subscriber","delipress"); ?>
                                            </a>
                                        </li>
                                        <li>
                                            <?php


                                            if($isConnector){
                                                $url = $this->optionServices->getPageUrl("connectors");
                                                ?>
                                                 <a
                                                    href="<?php echo $url; ?>"
                                                >
                                                    <?php _e("Delete","delipress"); ?>
                                                </a>
                                                <?php
                                            }
                                            else{
                                                $url = $this->listServices->getDeleteListUrl($list->getId());
                                                $preventOptinDeactivate = false;
                                                foreach($optins as $key => $optin){
                                                    $optinModel = new OptinModel();
                                                    $optinModel->setOptinById($optin->ID);

                                                    $totalListForOptin = $optinModel->getCountLists();

                                                    if($totalListForOptin == 1){
                                                        $preventOptinDeactivate = true;
                                                        break;
                                                    }
                                                }

                                                if(!$preventOptinDeactivate){
                                                    $title = __("Are you sure you want to delete the list ?", "delipress");
                                                    $msg = $list->getName();
                                                }
                                                else{
                                                    $title = __("Are you sure you want to delete the list ?", "delipress");
                                                    $msg   = $list->getName() . "<br />" . __("<strong>Warning</strong> : This list has Opt-In(s) linked to it. As a security, if you delete this list, we'll deactivate the Opt-In for you until you linked it to another list.", "delipress");
                                                }
                                                ?>

                                                <a
                                                    href="<?php echo $url; ?>"
                                                    class="js-prevent-delete-action"
                                                    data-title="<?php echo $title ?>",
                                                    data-message="<?php echo $msg; ?>"
                                                >
                                                    <?php _e("Delete","delipress"); ?>
                                                </a>
                                                <?php
                                            }
                                            ?>
                                        </li>
                                    </ul>
                                </nav>
                            </div>
                        </li>
                    <?php endforeach; ?>
                <?php else: ?>
                    <li class="delipress__list__nothing">
                        <span class="dashicons dashicons-warning"></span>
                        <?php esc_html_e('Sadly there is nothing to show here yet.', 'delipress'); ?>
                        <a href="<?php echo $this->listServices->getCreateUrl(); ?>">
                            <?php esc_html_e('Create your first list', 'delipress'); ?>
                        </a>
                    </li>
                <?php endif; ?>
            </ul>
            <?php if(!empty($listValid)): ?>
                <footer class="delipress__list__footer">
                    <div class="delipress__list__footer__item">
                        <input type="checkbox" id="select-all" class="delipress__checkbox__input" />
                        <label for="select-all" class="delipress__checkbox"></label>
                    </div>
                    <div class="delipress__list__footer__item">
                        <button type="submit" data-confirm="true" class="delipress__button delipress__button--action_choose_list delipress__button--soft delipress__button--small" data-action="<?php echo $this->listServices->getDeleteListsUrl(); ?>"><?php esc_html_e('Delete'); ?></button>
                    </div>
                </footer>
            <?php endif; ?>
        </form>

        <script>
            jQuery(document).ready(function(){
                var DelipressSelectAll           = require("javascripts/backend/SelectAll")
                var DelipressPreventChooseAction = require("javascripts/backend/PreventChooseAction")

                var selectAllClass = new DelipressSelectAll(
                    "#select-all",
                    ".delipress__checkbox__input",
                    "#form_footer"
                )
                selectAllClass.init()

                var preventChooseActionClass = new DelipressPreventChooseAction(
                    "#form_footer",
                    ".delipress__button--action_choose_list"
                )

                preventChooseActionClass.init()
            })
        </script>
    </div>
    <?php include DELIPRESS_PLUGIN_DIR_TEMPLATES_ADMIN . "/_pagination.php"; ?>
</section>

<?php if(!empty($listInvalid)): ?>
    <h2 class="delipress__opener delipress__opener--is-open js-delipress-opener">
        <?php esc_html_e('Previous Lists', "delipress"); ?> <a href="" class="dashicons dashicons-arrow-down-alt2"></a>
    </h2>

    <section class="delipress__section">
        <?php
            if(!$licenseStatusValid){
                MarkupIncentiveHelper::printMarkup('line', array(
                    'title'   => esc_html__('We’ve kept your old lists', 'delipress'),
                    'content' => esc_html__('You can synchronize them with your new email provider by upgrading.', 'delipress')
                ));
            }
        ?>
        <div class="delipress__list">
            <form method="post" action="<?php echo ($licenseStatusValid) ? $this->listServices->getDeleteListsUrl() : ""; ?>" id="form_footer_invalid">
                <ul class="delipress__list__content">
                    <?php foreach($listInvalid as $key => $list): ?>
                        <li class="delipress__list__item delipress__flex delipress__flex--center">
                            <?php if($licenseStatusValid): ?>
                                <div class="delipress__list__item__col-box">
                                    <input type="checkbox" id="<?php echo $list->getId(); ?>" class="delipress__checkbox__input" name="lists[]" value="<?php echo $list->getId(); ?>" />
                                    <label for="<?php echo $list->getId(); ?>" class="delipress__checkbox"></label>
                                </div>
                            <?php endif; ?>
                            <div class="delipress__f4">
                                <?php echo esc_html( $list->getName() ); ?>
                            </div>
                            <div class="delipress__f3">
                                <span class="delipress__list__item__num">
                                    <?php
                                        $total = $list->countSubscribers();
                                        echo $total;
                                    ?>
                                </span>
                                <?php
                                    echo
                                        esc_html(
                                            _n(
                                                "subscriber",
                                                "subscribers",
                                                ((int) $total === 0) ? 1 : $total,
                                                "delipress"
                                            )
                                        );

                                ?>

                            </div>
                            <div class="delipress__f1">
                                <?php esc_html_e('Color', 'delipress'); ?> <div class="delipress__list__item__color" style="background-color: <?php echo esc_attr($list->getColor() ); ?>"></div>
                            </div>
                            <div class="delipress__list__item__col-actions delipress__f5">
                                <!--<a href="#" class="delipress__button delipress__button--soft"><?php esc_html_e('Synchronize this list', 'delipress'); ?></a>-->
                            </div>
                        </li>
                    <?php endforeach; ?>
                </ul>
                <?php if($licenseStatusValid): ?>
                    <footer class="delipress__list__footer">
                        <div class="delipress__list__footer__item">
                            <input type="checkbox" id="select-all-no-valid" class="delipress__checkbox__input" />
                            <label for="select-all-no-valid" class="delipress__checkbox"></label>
                        </div>
                        <div class="delipress__list__footer__item">
                            <button type="submit" class="delipress__button delipress__button--action_choose delipress__button--soft delipress__button--small" data-action="<?php echo $this->synchronizeServices->getUrlExportProviderFormAdminPost($provider["key"]); ?>"><?php esc_html_e('Synchronize', 'delipress'); ?></button>
                        </div>
                        <div class="delipress__list__footer__item">
                            <button type="submit" class="delipress__button delipress__button--action_choose delipress__button--soft delipress__button--small" data-action="<?php echo $this->listServices->getDeleteListsUrl(); ?>"><?php esc_html_e('Delete'); ?></button>
                        </div>
                    </footer>
                <?php endif; ?>
            </form>
            <script>
                jQuery(document).ready(function(){
                    var DelipressSelectAll           = require("javascripts/backend/SelectAll")
                    var DelipressPreventChooseAction = require("javascripts/backend/PreventChooseAction")

                    var selectAllClass = new DelipressSelectAll(
                        "#select-all-no-valid",
                        ".delipress__checkbox__input",
                        "#form_footer_invalid"
                    )
                    selectAllClass.init()

                    var preventChooseActionClass = new DelipressPreventChooseAction(
                        "#form_footer_invalid",
                        ".delipress__button--action_choose"
                    )

                    preventChooseActionClass.init()
                })
            </script>
        </div>

    </section>

<?php endif; ?>

<?php include_once(DELIPRESS_PLUGIN_DIR_TEMPLATES_ADMIN . "/footer_no_forms.php"); ?>
