<?php

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Helpers\PostTypeHelper;
use Delipress\WordPress\Helpers\SourceSubscriberHelper;
use Delipress\WordPress\Helpers\ErrorFieldsNoticesHelper;
use Delipress\WordPress\Helpers\CodeErrorHelper;
use Delipress\WordPress\Helpers\PrepareModelHelper;
use Delipress\WordPress\Helpers\AdminFormValues;

use Delipress\WordPress\Models\ListModel;

if(!isset( $_GET["list_id"]) ){
    wp_redirect(admin_url());
    exit;
}

$errors  = ErrorFieldsNoticesHelper::getErrorNotices();

$listModel = new ListModel();
$listModel->setListByTermId((int) $_GET["list_id"]);

$subscriber   = PrepareModelHelper::getSubscriberFromUrl();
$idSubscriber = $subscriber->getId();
?>

<h1>
    <?php echo $listModel->getName(); ?> 
    <small>
        <?php if(empty($idSubscriber)): ?>
            <?php esc_html_e('Add subscriber', 'delipress'); ?>
        <?php else: ?>
            <?php esc_html_e('Edit subscriber', 'delipress'); ?>
        <?php endif; ?>
    </small>
</h1>


<div class="delipress__settings">

    <div class="delipress__settings__item delipress__flex">
        <div class="delipress__settings__item__label delipress__f2">
            <label for="email"><?php esc_html_e('Email', 'delipress'); ?></label>
        </div>
        <div class="delipress__settings__item__field delipress__f4">
                <input
                id="email"
                name="email"
                type="email"
                class="delipress__input <?php if(ErrorFieldsNoticesHelper::hasError(CodeErrorHelper::META_SUBSCRIBER_EMAIL) ): ?> delipress__input--error<?php endif; ?>"
                value="<?php echo esc_attr(AdminFormValues::displayOldValues("email", $subscriber->getEmail()) ); ?>"
                placeholder=""
                <?php if(!empty($idSubscriber)): ?>
                    readonly="readonly"
                <?php endif; ?>
            />
        </div>
        <div class="delipress__settings__item__help delipress__f5">
            <span class="delipress__mandatory"><?php esc_html_e("Required", "delipress"); ?></span>
            <?php ErrorFieldsNoticesHelper::displayError(CodeErrorHelper::META_SUBSCRIBER_EMAIL, $errors) ?>
        </div>
    </div>
    <div class="delipress__settings__item delipress__flex">
        <div class="delipress__settings__item__label delipress__f2">
            <label for="first_name"><?php esc_html_e('First name', 'delipress'); ?></label>
        </div>
        <div class="delipress__settings__item__field delipress__f4">
            <input
                id="first_name"
                name="first_name"
                type="text"
                class="delipress__input"
                value="<?php echo esc_attr(AdminFormValues::displayOldValues("first_name", $subscriber->getFirstName()) ); ?>"
                placeholder="" />
        </div>
        <div class="delipress__settings__item__help delipress__f5">
        </div>
    </div>
    <div class="delipress__settings__item delipress__flex">
        <div class="delipress__settings__item__label delipress__f2">
            <label for="last_name"><?php esc_html_e('Last name', 'delipress'); ?></label>
        </div>
        <div class="delipress__settings__item__field delipress__f4">
            <input
                id="last_name"
                name="last_name"
                type="text"
                class="delipress__input"
                value="<?php echo esc_attr(AdminFormValues::displayOldValues("last_name", $subscriber->getLastName()) ); ?>"
                placeholder="" />
        </div>
        <div class="delipress__settings__item__help delipress__f5">

        </div>
    </div>

    <input type="hidden" name="list_id" value="<?php echo $listModel->getId(); ?>" />
    <input type="hidden" name="<?php echo PostTypeHelper::META_SUBSCRIBER_SOURCE_REGISTER ?>" value="<?php echo SourceSubscriberHelper::ADMINISTRATION ?>" />

    <?php if(!empty($idSubscriber)): ?>
        <input type="hidden" name="subscriber_id" value="<?php echo $idSubscriber; ?>" />
        <button type="submit" class="delipress__button delipress__button--save"><?php esc_html_e('Edit subscriber', 'delipress'); ?></button>
    <?php else: ?>
        <button type="submit" class="delipress__button delipress__button--save"><?php esc_html_e('Add subscriber', 'delipress'); ?></button>
    <?php endif; ?>

</div>
