<?php

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

use Delipress\WordPress\Helpers\PrepareHelper;

use Delipress\WordPress\Models\ListModel;
use Delipress\WordPress\Models\SubscriberModel;

if(!isset($_GET["list_id"])){
    wp_safe_redirect(admin_url());
}


$paged          = (isset($_GET["paged"])) ? (int) $_GET["paged"] :  1;
$numberPerPage  = apply_filters(DELIPRESS_SLUG . "_list_subscribers_per_page", 20);

$listModel = new ListModel();
$listModel->setListByTermId((int) $_GET["list_id"]);
$provider      = $this->optionServices->getProvider();

$nbSubscribers = $countTotal = $listModel->countSubscribers();

$listSubscribers = $listModel->getSubscribers($paged, $numberPerPage);

?>

<?php include_once(DELIPRESS_PLUGIN_DIR_TEMPLATES_ADMIN . "/header_no_forms.php"); ?>

<h1><?php echo $listModel->getName(); ?> <small><?php esc_html_e("Subscribers", "delipress"); ?></small></h1>


<p class="delipress__intro">
    <?php
        echo sprintf(
            _n(
                "You have <strong>%s</strong> subscriber on this list.",
                "You have <strong>%s</strong> subscribers on this list.",
                ($nbSubscribers = $countTotal === 0) ? 1 : $nbSubscribers = $countTotal,
                "delipress"
            ),
            $nbSubscribers = $countTotal
        );
    ?>
</p>

<section class="delipress__section">
    <div class="delipress__list">
        <form action="<?php echo $this->listServices->getDeleteListsUrl(); ?>" method="post" id="form_list_subscribers">
            <ul class="delipress__list__content">
                <?php if(!empty($listSubscribers)): ?>
                    <?php foreach($listSubscribers as $key => $subscriber): ?>
                        <li class="delipress__list__item delipress__flex delipress__flex--center">
                            <div class="delipress__list__item__col-box">
                                <input type="checkbox" id="<?php echo $subscriber->getId() ?>" class="delipress__checkbox__input " name="subscribers[]" value="<?php echo $subscriber->getId(); ?>" />
                                <label for="<?php echo $subscriber->getId() ?>" class="delipress__checkbox"></label>
                            </div>
                            <div class="delipress__f4">
                                <a href="<?php echo $this->subscriberServices->getCreateUrl($listModel->getId(), $subscriber->getId()); ?>" class="delipress__list__item__title">
                                    <?php echo esc_html( $subscriber->getEmail() ); ?>
                                </a>
                            </div>
                            <div class="delipress__list__item__standard delipress__f3">
                                <?php esc_html_e('Status', 'delipress'); ?>  :
                                <span>
                                    <?php echo $subscriber->getStatus(true); ?>
                                </span>
                            </div>
                            <div class="delipress__list__item__standard delipress__f3">
                                <?php esc_html_e('Source', 'delipress'); ?>  :
                                <span>
                                    <?php if($subscriber->getSource()): ?>
                                        <?php echo esc_html($subscriber->getSource() ); ?>
                                    <?php else: ?>
                                        <?php esc_html_e('Unknown', 'delipress'); ?>
                                    <?php endif; ?>
                                </span>
                            </div>
                            <div class="delipress__list__item__standard delipress__f3">
                                <?php esc_html_e('Added on', 'delipress'); ?>
                                <strong><?php echo $subscriber->getOnListCreatedAt($listModel->getId()); ?></strong>
                            </div>
                            <div class="delipress__list__item__col-actions delipress__f1">
                                <nav class="delipress__more">
                                    <a href="" class="delipress__button delipress__button--soft">
                                        <span class="dashicons dashicons-arrow-down-alt2"></span>
                                    </a>
                                    <ul class="delipress__more__sub">
                                        <li>
                                            <a 
                                                href="<?php echo $this->subscriberServices->getDeleteSubscriberFromList($subscriber->getId(), $listModel->getId() );?>"
                                                class="js-prevent-delete-action"
                                                data-title="<?php esc_html_e("Are you sure you want to delete this subscriber ?", "delipress"); ?>",
                                                data-message="<?php echo esc_attr($subscriber->getEmail()); ?>"    
                                            >
                                                <?php esc_html_e("Delete", "delipress"); ?>
                                            </a>
                                        </li>
                                    </ul>
                                <nav>
                            </div>
                        </li>
                    <?php endforeach; ?>
                <?php else: ?>
                    <li class="delipress__list__nothing">
                        <span class="dashicons dashicons-warning"></span> <?php esc_html_e('Sadly there is nothing to show here yet.', 'delipress'); ?> <a href="<?php echo $this->subscriberServices->getCreateUrl($listModel->getId()); ?>"><?php esc_html_e('Add your first subscriber', 'delipress'); ?></a>
                    </li>
                <?php endif; ?>
            </ul>
            <?php if(!empty($listSubscribers)): ?>
                <footer class="delipress__list__footer">
                    <div class="delipress__list__footer__item">
                        <input type="checkbox" id="select-all-subscribers" class="delipress__checkbox__input">
                        <label for="select-all-subscribers" class="delipress__checkbox"></label>
                    </div>
                    <div class="delipress__list__footer__item">
                        <button type="submit" data-confirm="true" class="delipress__button delipress__button--action_choose_list_subscriber delipress__button--soft delipress__button--small" data-action="<?php echo $this->subscriberServices->getDeleteSubscribersFromList($listModel->getId() ); ?>"><?php esc_html_e('Delete'); ?></button>
                    </div>
                </footer>
            <?php endif; ?>
            <input
                type="hidden"
                name="list_id"
                value="<?php echo $listModel->getId(); ?>"
            />

        </form>
    </div>

    <?php include DELIPRESS_PLUGIN_DIR_TEMPLATES_ADMIN . "/_pagination.php"; ?>
</section>


<script>
    jQuery(document).ready(function(){
        var DelipressSelectAll = require("javascripts/backend/SelectAll")
        var DelipressPreventChooseAction = require("javascripts/backend/PreventChooseAction")

        var selectAllClass = new DelipressSelectAll(
            "#select-all-subscribers",
            ".delipress__checkbox__input",
            "#form_list_subscribers"
        )
        selectAllClass.init()

        var preventChooseActionClass = new DelipressPreventChooseAction(
            "#form_list_subscribers",
            ".delipress__button--action_choose_list_subscriber"
        )

        preventChooseActionClass.init()
    })
</script>


<?php

include_once(DELIPRESS_PLUGIN_DIR_TEMPLATES_ADMIN . "/footer_no_forms.php");

?>
