<?php

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

set_error_handler('__delipress__god_error_handler');
register_shutdown_function('__delipress__god_error_shutdown_handler');

function __delipress__god_error_shutdown_handler(){
    $lastError = error_get_last();
    if ($lastError !== null) {
        __delipress__god_error_handler($lastError['type'], $lastError['message'], $lastError['file'], $lastError['line']);
    }
}

function __delipress__god_error_handler($code, $message, $file, $line, $ctx = array()) {
    $allowTracking = get_option('__delipress__allow_tracking');

    if(!$allowTracking){
        return false;
    }

    $params = array(
        "message" => $message,
        "file"    => $file,
        "code"    => $code,
        "line"    => $line
    ); 

    $authorizeError = __delipress__god_authorize_error($file);

    if(!$authorizeError){
        return;
    }

    $alreadyExist = __delipress__god_error_already_exist($params);
    
    if($alreadyExist){
        return;
    }

    __delipress__god_prepare_background_process($params);
}

/**
 *
 * @param array $params
 * @return string
 */
function __delipress__god_serialize_error($params){
    return md5(vsprintf("%s-%s-%s-%s", array($params["file"], $params["line"], $params["code"], $params["message"])));
}

/**
 * Save error in transient
 *
 * @param array $params
 * @return void
 */
function __delipress__god_save_error($params){
    
    $serialize = __delipress__god_serialize_error($params);

    if ( false === ( $transientError = get_transient( __delipress__NAME_TRANSIENT_ERROR ) ) ) {
        $transientError = array();
        $transientError[$serialize] = $params;
        set_transient(__delipress__NAME_TRANSIENT_ERROR, $transientError);
    }
    else{

        if(!array_key_exists($serialize, $transientError)){
            $transientError[$serialize] = $params;
            set_transient(__delipress__NAME_TRANSIENT_ERROR, $transientError);
        }
    }

}

function __delipress__god_prepare_background_process($paramsError){

    global $wp_version;

    $params = array_merge(
        array(
            "wp_infos" => array(
                "wp_version"       => $wp_version,
            ),
            "home_url"     => home_url(),
            "php_version"  => PHP_VERSION,
            "server_infos" => __delipress__god_get_info_server()
        ),
        $paramsError
    );

    __delipress__god_save_error($params);
}

/**
 *
 * @param string $file
 * @return boolean
 */
function __delipress__god_authorize_error($file){
    global $__delipress__wp_god;

    switch($__delipress__wp_god["type_development"]){
        case "plugin":
            $verify = sprintf("%s/%s", PLUGINDIR, $__delipress__wp_god["basename"]);
            break;
    }
    
    if(strpos(str_replace("\\", "/", $file), $verify) === false){
        return false;
    }

    return true;
}

/**
 *
 * @param array $params
 * @return boolean
 */
function __delipress__god_error_already_exist($params){
    $transient = get_transient(__delipress__NAME_TRANSIENT_ERROR_ALREADY_SEND);
    $md5       = __delipress__god_serialize_error($params);

    if(!$transient){
        $transient   = array();
        $transient[] = $md5;
        set_transient(__delipress__NAME_TRANSIENT_ERROR_ALREADY_SEND, $transient);
        return false;
    }
    
    
    if( in_array($md5, $transient) ) {
        return true;
    }

    $transient[] = $md5;
    set_transient(__delipress__NAME_TRANSIENT_ERROR_ALREADY_SEND, $transient, apply_filters("__delipress__god_time_already_send", 43200));
    return false;
}